/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

require([
    "aps/load",
    "aps/Memory",
    "aps/xhr",
    "dijit/registry",
    "dojox/mvc/at",
    "dojox/mvc/getPlainValue",
    "dojox/mvc/getStateful",
    "./js/common.js",
    "./js/messages.js",
    "./js/wizardData.js"
], function (
    load,
    Memory,
    xhr,
    registry,
    at,
    getPlainValue,
    getStateful,
    common,
    messages,
    wizardData
) {
    var tenant = aps.context.vars.tenant,
        profile = tenant.profile,
        enableOptions = [
            {value: "1", label: _("Enabled")},
            {value: "0", label: _("Disabled")}
        ],
        adminModel = getStateful({
            login: "",
            email: "",
            firstName: "",
            lastName: ""
        });


    function goToList() {
        aps.apsc.gotoView(common.getRelatedViewId('list'));
    }

    load(["aps/PageContainer", {id: "apsPageContainer"}, [
        ["aps/FieldSet", {title: _("General")}, [
            ["aps/TextBox", {
                id: "login",
                label: _("Login"),
                required: true,
                trim: true,
                value: at(adminModel, "login")
            }],
            ["aps/TextBox", {
                id: "email",
                label: _("Email"),
                required: true,
                trim: true,
                pattern: '^[^\\s@]+@[^\\s@]+\\.[^\\s@.]+$',
                invalidMessage: _('Please enter a valid email.'),
                value: at(adminModel, "email")
            }],
            ["aps/TextBox", {
                id: "firstName",
                label: _("First name"),
                required: false,
                trim: true,
                value: at(adminModel, "firstName")
            }],
            ["aps/TextBox", {
                id: "lastName",
                label: _("Last name"),
                required: false,
                trim: true,
                value: at(adminModel, "lastName")
            }]
        ]],
        ["aps/Output", {
            class: 'space-before-element-block'
        }]
    ]]).then(function () {
        aps.app.onSubmit = function () {
            var page = registry.byId("apsPageContainer");
            if (!page.validate()) {
                aps.apsc.cancelProcessing();
                return;
            }

            xhr.get("/aps/2/resources/" + tenant.aps.id + "/loginExists", {
                query: {
                    login: adminModel.login,
                    datacenterId: ''
                }
            }).then(function (existing) {
                if (existing) {
                    messages.displayWarning(_("This login already exists."));
                    aps.apsc.cancelProcessing();
                    return;
                }
                xhr("/aps/2/resources/" + tenant.aps.id + "/administrators/", {
                    method: "POST",
                    query: {
                        datacenterId: ''
                    },
                    data: JSON.stringify(getPlainValue(adminModel)),
                    headers: {"Content-Type": "application/json"}
                }).then(function () {
                    var message = {
                        text : _("The administrator account has been created. The activation message has been sent to email '{0}'. To activate the account, please follow the instructions from this message.").replace("{0}", adminModel.email),
                        type : "info"
                    };
                    wizardData.setWizardData({message: message}, common.getRelatedViewId('list'));
                    goToList();
                }, messages.displayError);
            }, messages.displayError);
        };
    });

    aps.app.onCancel = goToList;
});
