/**
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

require([
    "aps/ResourceStore",
    "dojo/Deferred",
    "aps/WizardData",
    "aps/xhr",
    "dijit/registry",
    "aps/load",
    "./js/common.js"
], function (ResourceStore, Deferred, WizardData, xhr, registry, load, common) {
    var userRequest = new Deferred(),
        tenant = aps.context.vars.tenant,
        user = aps.context.params.user,
        isNew = common.getCurrentView() === "ccp--suwizard--overview";

    if (isNew) {
        if (typeof (aps.context.params.objects[0]) != 'undefined') {
            var userData = aps.context.params.objects[0],
                login = aps.context.params.user.login.toLowerCase(),
                notifications = userData.notifications || [],
                dataForPrevStep = {};

            userRequest.resolve(userData);

            dataForPrevStep[login] = userData;
            WizardData.put(dataForPrevStep);
        } else {
            load(["aps/PageContainer", {id: "apsPageContainer"}, [
                ["aps/Message", {
                    description: _('The Cyber Protection service will not be activated for this user due to lack of resources.'),
                    type: "warning"
                }
                ]
            ]]);
        }
    } else {
        var resourceStore = new ResourceStore({
            apsType: common.TYPES.USERS,
            target: "/aps/2/resources/?eq(serviceUserId," + aps.context.params.user.aps.id + ")"
        });
        resourceStore.query().then(function (userList) {
            var ownCloudUser = {user_quota: "-"};
            if (userList.length > 0)
                ownCloudUser = userList[0];
            userRequest.resolve(ownCloudUser);
        });
        notifications = aps.context.params.user.notifications || [];
    }

    userRequest.then(function (cloudBackupUser) {
        function getOverviewValue(counterField) {
            return counterField == common.QUOTA_UNLIMITED_VALUE ? _('Unlimited') : counterField;
        }

        function getStorageOverview(storageLimit) {
            return storageLimit == common.QUOTA_UNLIMITED_VALUE ? _('Unlimited') : storageLimit / common.BYTES_IN_GB;
        }

        function printNotification(notifications, value) {
            return notifications.includes(value) ? _('Yes') : _('No');
        }

        xhr.get("/aps/2/resources/" + tenant.aps.id + "/profile").then(function (profiles) {
            var userQuota = profiles.length ? profiles[0].userQuota : common.USER_QUOTA.STRICT;
            let items = [];
            common.getAvailableCountersForArea('quota_controls_ccpv1_new_user').forEach(function (counter) {
                if (!cloudBackupUser.hasOwnProperty('offeringItems')) {
                    cloudBackupUser.offeringItems = [];
                }

                let offeringItem = common.getUserOfferingItem(cloudBackupUser, counter.name, true);
                var itemExists = items.filter((item) => {
                    return item[1].label == counter.label
                });

                if (!itemExists.length) {
                    if (counter.schema == 'storage') {
                        items.push(["aps/Output", {
                            label: counter.label,
                            value: getStorageOverview(offeringItem.limit)
                        }]);
                    } else {
                        items.push(["aps/Output", {
                            label: counter.label,
                            visible: tenant[counter.name] && tenant[counter.name].limit,
                            value: getOverviewValue(offeringItem.limit)
                        }]);
                    }
                }
            });
            load(
                ["aps/PageContainer", {id: "apsPageContainer"}, [
                    ["aps/FieldSet", [
                        ["aps/Output", {
                            label: _("User name"),
                            value: common.escapeAngularBrackets(user.displayName + ' (' + user.login + ')')
                        }],
                        ["aps/Output", {
                            label: _('Administrator privileges'),
                            value: cloudBackupUser.privileged ? _('Yes') : _('No')
                        }]
                    ]],
                    ["aps/FieldSet", {
                        escapeHTML: false,
                        title: _('Notifications')
                    }, [
                        ["aps/FieldSet", {
                            label: "MANAGEMENT PORTAL",
                            title: false
                        }],
                        ["aps/Output", {
                            label: _('Quota overuse notifications'),
                            value: printNotification(notifications, 'quota')
                        }],
                        ["aps/Output", {
                            label: _('Scheduled usage reports'),
                            value: printNotification(notifications, 'reports')
                        }],
                        ["aps/Output", {
                            class: 'space-before-element'
                        }],
                        ["aps/FieldSet", {
                            label: "CYBER PROTECTION",
                            title: false
                        }],
                        ["aps/Output", {
                            label: _('Failure notifications'),
                            value: printNotification(notifications, 'backup_error')
                        }],
                        ["aps/Output", {
                            label: _('Warning notifications'),
                            value: printNotification(notifications, 'backup_warning')
                        }],
                        ["aps/Output", {
                            label: _('Success notifications'),
                            value: printNotification(notifications, 'backup_info')
                        }],
                        ["aps/Output", {
                            label: _('Daily recap about active alerts'),
                            value: printNotification(notifications, 'backup_daily_report')
                        }]
                    ]],
                    ["aps/FieldSet", {
                        escapeHTML: false,
                        title: _('Quotas'),
                        visible: userQuota != common.USER_QUOTA.OFF
                    }, (userQuota == common.USER_QUOTA.OFF ? [] : items)]
                ]]
            );
        });
    });
});

