/**
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

/*
 System phrases for localization parser
 _("All");
 */
define([
    "aps/i18n",
    "aps/xhr",
    "dijit/registry",
    "dojo/Deferred",
    "dojo/_base/lang",
    "dojox/mvc/equals",
    "aps/ResourceStore"
], function (
    _,
    xhr,
    registry,
    Deferred,
    lang,
    equals,
    Store
) {
    return {
        APP_ID: "http://www.acronis.com/aps/cloud-backup-v1",

        SERVICE_TITLE: _("Backup"),

        BYTES_IN_GB: 1024 * 1024 * 1024,

        QUOTA_UNLIMITED_VALUE: -1,

        getCountersToOfferingItems: function () {
            var aliases = {
                    'O365SeatsCount': 'MailboxCount',
                    'PublicIpsCount': 'PublicIPsCount'
                },
                counters = {
                    'StorageUsage': {
                        iconClass: 'i-cloud-storage-o--16',
                        schema: 'storage',
                        label: this.isCcpV1() ? _('Cloud Storage {unit}') : _('Cloud Storage')
                    },
                    'WorkstationCount': {
                        iconClass: 'i-workstations-o--16',
                        schema: 'machines',
                        label: this.isCcpV1() ? _('Physical workstations') : _('Workstations')
                    },
                    'ServerCount': {
                        iconClass: 'i-server-o--16',
                        schema: 'machines',
                        label: this.isCcpV1() ? _('Physical servers') : _('Servers')
                    },
                    'VmCount': {
                        iconClass: 'i-virtual-machines-o--16',
                        schema: 'machines',
                        label: this.isCcpV1() ? _('Virtual machines') : _('Virtual Machines')
                    },
                    'MobileDeviceCount': {
                        iconClass: 'i-mobile-devices-o--16',
                        schema: 'devices',
                        label: this.isCcpV1() ? _('Mobile devices') : _('Mobile Devices')
                    },
                    'WebHostingServerCount': {
                        iconClass: 'i-web-hosting-server-o--16',
                        schema: 'servers',
                        label: this.isCcpV1() ? _('Web Hosting Servers') : _('Web Hosting Servers')
                    },
                    'WebsiteCount': {
                        iconClass: 'i-website-o--16',
                        schema: 'servers',
                        label: this.isCcpV1() ? _('Websites') : _('Websites')
                    },
                    'ComputePointsCount': {
                        iconClass: 'i-cp-used-o--16',
                        schema: 'unit',
                        label: this.isCcpV1() ? _('Number of compute points') : _('Compute points')
                    },
                    'LocalStorageUsage': {
                        iconClass: 'i-local-backup-o--16',
                        schema: 'storage',
                        label: this.isCcpV1() ? _('Local Storage usage') : _('Local Storage')
                    },
                    'MailboxCount': {
                        iconClass: 'i-mailboxes-o--16',
                        schema: 'unit',
                        label: this.isCcpV1() ? _('Number of office 365 seats') : _('Office 365 seats')
                    },
                    'DrStorageUsage': {
                        iconClass: 'i-dr-storage-o--16',
                        schema: 'storage',
                        label: this.isCcpV1() ? _('Disaster recovery storage usage') : _('Disaster recovery storage')
                    },
                    'PublicIPsCount': {
                        iconClass: 'i-public-ips-o--16',
                        schema: 'unit',
                        label: this.isCcpV1() ? _('Number of public IP addresses') : _('Public IP addresses')
                    },
                    'CloudServersCount': {
                        iconClass: 'i-cloud-server-o--16',
                        schema: 'unit',
                        label: this.isCcpV1() ? _('Number of cloud servers') : _('Cloud servers')
                    },
                    'InternetAccess': {
                        iconClass: 'i-internet-access-o--16',
                        schema: 'feature',
                        label: _('Internet access')
                    },
                    'O365Mailboxes': {iconClass: 'i-mail-o--24', schema: 'feature', label: _('Office 365 Mailboxes')},
                    'O365OneDrive': {iconClass: 'i-one-drive--16', schema: 'feature', label: _('Office 365 OneDrive')},
                    'O365SharePointSitesCount': {
                        iconClass: 'i-o-365-sharepoint-o--16',
                        schema: 'feature',
                        label: this.isCcpV1() ? _('Office 365 SharePoint sites') : _('Office 365 SharePoint Online')
                    },
                    'GsuiteGoogleTeamDrive': {
                        iconClass: 'i-g-suite-team--16',
                        schema: 'feature',
                        label: _('G Suite Shared Drive')
                    },
                    'GsuiteGoogleMail': {
                        iconClass: 'i-gmail--16',
                        schema: 'feature',
                        label: _('Gmail (incl. Calendar, Contacts)')
                    },
                    'GsuiteGoogleDrive': {iconClass: 'i-my-drive--16', schema: 'feature', label: _('Google Drive')},
                    'GsuiteSeatsCount': {
                        iconClass: 'i-g-suite--16',
                        schema: 'unit',
                        label: this.isCcpV1() ? _('Number of G Suite seats') : _('G Suite seats')
                    },
                    'O365TeamsCount': {
                        iconClass: 'i-office-365-teams--16',
                        schema: 'unit',
                        label: this.isCcpV1() ? _('Number of Office 365 Teams') : _('Office 365 Teams')
                    }
                };

            for (var alias in aliases) {
                var counterName = aliases[alias];
                counters[alias] = lang.clone(counters[counterName]);
            }

            return counters;
        },

        ALL_COUNTERS_MAP: null,

        COUNTERS_LEGEND_SCHEMAS: function () {
            return {
                'feature': {},
                'unit': {
                    noneLegend: _("None"),
                    limitedLegend: _("${usage} ${usageUnit} of ${limit} ${limitUnit} used"),
                    unlimitedLegend: _("${usage} ${usageUnit} used")
                },
                'storage': {
                    noneLegend: _("None"),
                    limitedLegend: _("${usage} ${usageUnit} of ${limit} ${limitUnit} used"),
                    unlimitedLegend: _("${usage} ${usageUnit} used")
                },
                'machines': {
                    limitedLegend: _("${usage} of ${limit} machines protected"),
                    zeroUsageLegend: _("${limit} machines can be protected"),
                    unlimitedLegend: _("${usage} machines protected")
                },
                'devices': {
                    limitedLegend: _("${usage} of ${limit} devices protected"),
                    zeroUsageLegend: _("${limit} devices can be protected"),
                    unlimitedLegend: _("${usage} devices protected")
                },
                'servers': {
                    limitedLegend: _("${usage} of ${limit} servers protected"),
                    zeroUsageLegend: _("${limit} servers can be protected"),
                    unlimitedLegend: _("${usage} servers protected")
                },
                'websites': {
                    limitedLegend: _("${usage} of ${limit} websites protected"),
                    zeroUsageLegend: _("${limit} websites can be protected"),
                    unlimitedLegend: _("${usage} websites protected")
                }
            }
        },

        // Use * to display all counters in specific area,
        // use ['Counter1', ... , 'CounterN'] to display some specific list
        COUNTERS_AVAILABILITY_MAP: {
            'resources_tile_ccpv2': '*',
            'quota_list_view_ccpv2': ["WorkstationCount", "ServerCount", "VmCount", "MobileDeviceCount", "WebHostingServerCount", "WebsiteCount"],
            'user_quotas': ["StorageUsage", "WorkstationCount", "ServerCount", "VmCount", "MobileDeviceCount", "WebHostingServerCount", "WebsiteCount"],
            'devices_count_ccpv2': ["WorkstationCount", "ServerCount", "VmCount", "MobileDeviceCount","O365TeamsCount"],
            'storage_usage_only': ["StorageUsage"],
            'quota_controls_ccpv1_users_list': [
                'WorkstationCount',
                'ServerCount',
                'VmCount',
                'MobileDeviceCount',
                'WebHostingServerCount',
                'WebsiteCount'
            ],
            'quota_controls_ccpv1_new_user' : ["StorageUsage", "WorkstationCount", "ServerCount", "VmCount", "MobileDeviceCount", "WebHostingServerCount", "WebsiteCount"],
            'quota_controls_ccpv1_edit_user' : ["StorageUsage", "WorkstationCount", "ServerCount", "VmCount", "MobileDeviceCount", "WebHostingServerCount", "WebsiteCount"],
            'quota_controls_ccpv1_view_user' : ["StorageUsage", "WorkstationCount", "ServerCount", "VmCount", "MobileDeviceCount", "WebHostingServerCount", "WebsiteCount"]
        },

        USER_AREAS : {
            'user_quotas' : true,
            'quota_controls_ccpv1_new_user' : true,
            'quota_controls_ccpv1_edit_user' : true,
            'quota_controls_ccpv1_view_user' : true
        },

        getBackupAccountResources: function (tenant) {
            var self = this;
            var deferred = new Deferred();
            xhr('/aps/2/resources/' + tenant.aps.subscription + '/resources')
                .then(function (subscriptionResources) {
                    var availableResources = [];
                    subscriptionResources.forEach(function (resource) {
                        if (self.isBackupAccountResource(resource)) {
                            availableResources.push(resource);
                        }
                    });
                    deferred.resolve(availableResources);
                }, deferred.reject);
            return deferred;
        },

        getUserOfferingItem: function (user, counterName, createIfNotExist) {
            var offeringItemName = window.offeringItemsMap[counterName] || '';

            if (!user.offeringItems) {
                user.offeringItems = [];
            }

            var filtered = user.offeringItems.filter(function (oi) {
                return oi.name === offeringItemName;
            });

            if (!filtered.length && createIfNotExist) {
                let offeringItem = {name: offeringItemName, limit: 0};
                user.offeringItems.push(offeringItem);
                return offeringItem;
            }

            return filtered[0] || null;
        },

        isStorage: function (counterName) {
            var standardCounterName = this.getStandardCounterName(counterName);
            return standardCounterName && this.getCountersToOfferingItems()[standardCounterName].schema === 'storage';
        },

        getTenantVisibleQuotas: function (tenant, areaName = '', allowZeroLimit = true) {
            var visibleQuotas = {},
                availableCounters = this.COUNTERS_AVAILABILITY_MAP[areaName] || [];

            for (var counterName in window.allCounters) {
                if (areaName && !availableCounters.includes(counterName) && availableCounters !== '*') {
                    continue;
                }
                var countersInEditions = window.allCounters[counterName].map(function(counter) { return counter.name; });
                // Include the edition base name as well
                countersInEditions.push(counterName);
                countersInEditions.forEach(function (edition) {
                    let hasLimit = tenant.hasOwnProperty(edition) && tenant[edition].hasOwnProperty('limit');
                    if (hasLimit && (allowZeroLimit || tenant[edition].limit)) {
                        visibleQuotas[counterName] = edition;
                    }
                });
            }

            return visibleQuotas;
        },

        initCounters(resourceId) {
            let deferred = new Deferred();
            resourceId = resourceId ||
                (aps.context.vars.tenant && aps.context.vars.tenant.aps.id) ||
                (aps.context.vars.enduser && aps.context.vars.enduser.tenant && aps.context.vars.enduser.tenant.aps.id) ||
                (aps.context.vars.globals && aps.context.vars.globals.aps.id);
            if (resourceId) {
                xhr.get("/aps/2/resources/" + resourceId + "/allCounters").then(function (allCountersInfo) {
                    window.allCounters = allCountersInfo['counters'];
                    window.offeringItemsMap = allCountersInfo['offering_items'];
                    deferred.resolve();
                }, deferred.reject);
            } else {
                deferred.resolve();
            }

            return deferred;
        },

        getFullCountersList() {
            var list = [];
            for (var standardCounterName in window.allCounters) {
                list.push(standardCounterName);
                var counterEditions = window.allCounters[standardCounterName].map(function(counter) { return counter.name; });
                list = list.concat(counterEditions);
            }

            return list;
        },

        isBackupAccountResource: function (resource) {
            var editionProperties = this.COUNTERS_AVAILABILITY_MAP["user_quotas"],
                allowedApsType = this.TYPES.TENANT,
                standardCounterName = this.getStandardCounterName(resource.property);

            return editionProperties.some(function (possibleProperty) {
                return resource.apsType === allowedApsType && standardCounterName === possibleProperty;
            });
        },

        getStandardCounterName(counterName) {
            for (var standardCounterName in window.allCounters) {
                var countersInEditions = window.allCounters[standardCounterName].map(function(counter) { return counter.name; });
                // Include the edition base name as well
                countersInEditions.push(standardCounterName);
                if (countersInEditions.indexOf(counterName) !== -1) {
                    return standardCounterName;
                }
            }

            return false;
        },

        getAvailableCountersForArea: function (areaName, assoc = false) {
            var allCounters = window.allCounters,
                result = assoc ? {} : [],
                availableCounters = this.COUNTERS_AVAILABILITY_MAP[areaName] || [],
                isForUser = this.USER_AREAS[areaName];

            for (let [counterName, counterData] of Object.entries(this.getCountersToOfferingItems())) {
                if (areaName && !availableCounters.includes(this.getStandardCounterName(counterName)) && availableCounters !== '*') {
                    continue;
                }
                var legendSchema = counterData['schema'] || '',
                    schemasLegend = this.COUNTERS_LEGEND_SCHEMAS(),
                    legendDefaults = schemasLegend[legendSchema] || {},
                    stdCounter = lang.mixin(counterData, {
                        name: counterName,
                        legend: legendDefaults
                    });
                if (assoc) {
                    result[counterName] = stdCounter;
                } else {
                    result.push(stdCounter);
                }

                if (allCounters[counterName] === undefined) {
                    continue;
                }
                for (let counterInEdition of allCounters[counterName]) {
                    if (isForUser && !counterInEdition.isForUser) {
                        continue;
                    }
                    let counter =  lang.mixin({}, stdCounter, {name: counterInEdition.name});
                    if (assoc) {
                        result[counterInEdition.name] = counter ;
                    } else {
                        result.push(counter)
                    }
                }
            }

            return result;
        },

        getCounterData: function(counterName) {
            return this.getAvailableCountersForArea('', true)[counterName];
        },

        USER_QUOTA: {
            OFF: 0,
            STRICT: 1,
            SOFT: 2
        },

        USER_PRIVILEGED: {
            NO: 0,
            YES: 1
        },

        STATUS: {
            INACTIVE: "-1",
            DISABLED: "0",
            ENABLED: "1"
        },

        NOTIFICATION_LEVEL: {
            OFF: 0,
            LESS: 1,
            MORE: 3,
            ALL: 7
        },

        // required because APS doesn't store empty arrays, and we need to distinguish between "empty" and "not set"
        EMPTY_NOTIFICATIONS: ["false"],

        NOTIFICATION: {
            QUOTA: "quota",
            REPORTS: "reports",
            BACKUP_ERROR: "backup_error",
            BACKUP_WARNING: "backup_warning",
            BACKUP_INFO: "backup_info",
            BACKUP_DAILY_REPORT: "backup_daily_report"
        },

        RESELLER_NOTIFICATIONS: [
            "quota",
            "reports",
            "backup_daily_report"
        ],

        NOTIFICATION_MANAGEMENT: {
            DISABLE: false,
            ENABLE: true
        },

        STORAGE_POLICY: {
            PARENT: "0",
            OWN: "1"
        },

        STORAGE_INHERITED: {
            NO: 0,
            YES: 1
        },

        TYPES: {
            USERS: "http://acronis.com/aps/cloud-backup-v1/users/7.9",
            TENANT: "http://acronis.com/aps/cloud-backup-v1/tenant/9.8",
            GLOBALS: "http://acronis.com/aps/cloud-backup-v1/globals/9.6",
            RESELLER: "http://acronis.com/aps/cloud-backup-v1/reseller/1.0",
            PROFILE: "http://acronis.com/aps/cloud-backup-v1/backup-profile/5.1",
            DATACENTER: "http://acronis.com/aps/cloud-backup-v1/datacenter/4.1",
            ADMIN: "http://acronis.com/aps/cloud-backup-v1/admin/4.0",
            MINIMAL_COMMITMENT_TIER: "http://acronis.com/aps/cloud-backup-v1/minimal-commitment-tier/4.0"
        },

        USER_STATUS: {
            ERROR: "-1",
            INACTIVE: "0",
            ACTIVE: "1",
            IN_PROGRESS: "2",
            NOT_ACTIVATED: "3"
        },

        BACKUP_LOCATIONS: {
            ONLY_CLOUD: "0",
            LOCAL_AND_CLOUD: "1"
        },

        PACKAGE_TYPE: {
            PREMIUM: 'premium'
        },
        GROUP_TYPE: {
            CUSTOMER: "0",
            PARTNER: "1"
        },
        TENANT_TYPE: {
            RESELLER: "RESELLER",
            CUSTOMER: "CUSTOMER",
            PARTNER: "PARTNER"
        },
        TENANT_EDITIONS: {
            ADVANCED: "Adv",
            PROTECT_ADVANCED: "PAdv",
            DISASTER_RECOVERY: "Dre",
            PROTECT_DISASTER_RECOVERY: "PDre",
            PROTECT: "P"
        },

        formatStorageSize: function (value) {
            var units = [_('B'), _('KB'), _('MB'), _('GB'), _('TB'), _('PB'), _('EB')];
            var multiplier = 1024;
            while (value >= multiplier) {
                value = value / multiplier;
                units.shift();
            }
            var decimalPlaces = 1;
            value = Number(value);
            value = value.toFixed(decimalPlaces) == Math.round(value) ? Math.round(value) : value.toFixed(decimalPlaces);
            return value + " " + units.shift();
        },

        isCcpV1: function () {
            return this.getCurrentView().startsWith('ccp');
        },

        printNotification: function (notifications, value) {
            return this.transformNotificationsToArray(notifications, []).includes(value) ? _('Yes') : _('No');
        },

        transformNotificationsToObject: function (notifications) {
            if (!Array.isArray(notifications)) {
                return {};
            }

            var notificationsObj = {};
            Object.values(this.NOTIFICATION).forEach(function (name) {
                notificationsObj[name] = false;
            });

            if (equals(notifications, this.EMPTY_NOTIFICATIONS)) {
                return notificationsObj;
            }

            notifications.forEach(function (name) {
                if (name in notificationsObj) {
                    notificationsObj[name] = true;
                }
            });

            return notificationsObj;
        },

        transformNotificationsToArray: function (notifications, emptyValue) {
            emptyValue = emptyValue || this.EMPTY_NOTIFICATIONS;
            if (Array.isArray(notifications)) {
                return notifications;
            }

            if (!notifications) {
                return emptyValue;
            }

            var notificationsArray = [];
            var validNotifications = Object.values(this.NOTIFICATION);

            Object.keys(notifications).forEach(function (name) {
                if (validNotifications.includes(name) && notifications[name]) {
                    notificationsArray.push(name);
                }
            });

            return notificationsArray.length ? notificationsArray : emptyValue;
        },

        formatLocalDateString: function (date, locale) {
            locale = locale.replace('_', '-');
            try {
                return date.toLocaleString(locale);
            } catch (e) {
                return date.toLocaleString();
            }
        },

        escapeAngularBrackets: function (string) {
            return string ? string.replace(/</g, '&lt;').replace(/>/g, '&gt;') : string;
        },

        getRelatedViewId: function (view) {
            var uri = this.getCurrentView();
            if (uri === undefined) {
                return view;
            }
            var parts = uri.split('--').slice(0, -1);
            parts.push(view);
            return parts.join('--');
        },

        getCurrentView: function () {
            return typeof aps.context.viewId === "undefined" ? aps.context.view.id.split('#').pop() : aps.context.viewId;
        },

        getLanguage: function (locale) {
            return locale.replace(/_.*/, '');
        },

        cmpType: function (originType, inheritType) {
            var regexp = new RegExp(/^(.+\/)(\d+.\d+)$/);
            var originMatches = regexp.exec(originType);
            if (!originMatches || originMatches.length !== 3) {
                return false;
            }

            var inheritMatches = regexp.exec(inheritType);
            if (!inheritMatches || inheritMatches.length !== 3) {
                return false;
            }

            var originURI = originMatches[1],
                inheritURI = inheritMatches[1];

            return originURI === inheritURI;
        },

        isUsers: function (apsType) {
            return this.cmpType(apsType, this.TYPES.USERS);
        },

        isTenant: function (apsType) {
            return this.cmpType(apsType, this.TYPES.TENANT);
        },

        isGlobals: function (apsType) {
            return this.cmpType(apsType, this.TYPES.GLOBALS);
        },

        isReseller: function (apsType) {
            return this.cmpType(apsType, this.TYPES.RESELLER);
        },

        isProfile: function (apsType) {
            return this.cmpType(apsType, this.TYPES.PROFILE);
        },

        getBackupProfile: function (tenant) {
            var deferred = new Deferred();
            var store = new Store({target: "/aps/2/resources/" + tenant.aps.id + "/profile"});
            if (tenant.profile) {
                deferred.resolve(tenant.profile);
            } else {
                store.query().then(function (profiles) {
                    profiles && profiles.length ? deferred.resolve(profiles[0]) : deferred.resolve(null);
                }, deferred.reject);
            }
            return deferred;
        },

        getUserQuota: function (profile) {
            return profile ? Number(profile.userQuota) : this.USER_QUOTA.STRICT;
        },

        getMinimalCommitmentLevelName: function (level) {
            var n = parseInt(level, 10);
            if (isNaN(n)) return '';
            if (n < -1) return _("Fixed custom commitment");
            if (n == -1) return _("No commitment");
            if (n === 0) return _("Minimum");
            return String(n);
        },
        genId: function (widgetType) {
            return dijit.registry.getUniqueId(widgetType);
        },
        loginToConsole: function (backupAccount) {
            var deferred = new Deferred();
            if (!backupAccount) {
                deferred.reject();
                return deferred;
            }
            xhr.get("/aps/2/resources/" + backupAccount.aps.id + "/loginByToken").then(function (uri) {
                deferred.resolve(uri);
            }, deferred.reject);

            return deferred;
        }
    };
});
