/**
 * @Copyright © 2002-2018 Acronis International GmbH. All rights reserved
 */

define([
    'aps/Tile',
    'aps/FieldSet',
    'aps/Output',
    "dojo/_base/lang",
    './../utils',
    './../../common',
    './getResourceOutput',
    './getStorageOutput',
    './getTenantButtons'
], function (
    Tile,
    FieldSet,
    Output,
    lang,
    utils,
    common,
    getResourceOutput,
    getStorageOutput,
    getTenantButtons
) {

    function createFieldSet(tenant, countersList) {
        var fs = new FieldSet({
            gridSize: 'md-12 xs-12'
        });

        countersList.forEach(function (counter) {
            if (tenant[counter.name] && tenant[counter.name].limit) {
                var tileData = lang.mixin({
                    gridSize: 'md-4 xs-12',
                    label: counter.label
                }, counter.legend);

                switch (counter.schema) {
                    case 'feature':
                        fs.addChild(new Output(lang.mixin({
                            value: _('Enabled')
                        }, tileData)));
                        break;
                    case 'storage':
                        fs.addChild(getStorageOutput(lang.mixin({
                            usage: tenant[counter.name].usage || 0,
                            limit: tenant[counter.name].limit || 0
                        }, tileData)));
                        break;
                    default:
                        fs.addChild(getResourceOutput(lang.mixin({
                            usage: tenant[counter.name].usage || 0,
                            limit: tenant[counter.name].limit || 0
                        }, tileData)));
                }
            }
        });

        return fs;
    }

    function getTenantResourcesTile(tenant, subscriptionId, trial, canAdjustLimits, countersList) {

        var buttons = getTenantButtons(tenant, subscriptionId, trial, canAdjustLimits),
            tile = new Tile({
            title: _('Subscription Limits'),
            gridSize: 'md-8 xs-12',
            buttons: [buttons]
        });

        tile.addChild(createFieldSet(tenant, countersList));

        return tile;
    }

    return getTenantResourcesTile;
});

