/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

define([
    "dojo/_base/declare",
    "dojox/mvc/at",
    "dojox/mvc/getStateful",
    "dojox/mvc/getPlainValue",
    "aps/_PopupView",
    "aps/xhr",
    "./../utils",
    "./../../messages"
], function (
    declare,
    at,
    getStateful,
    getPlainValue,
    _PopupView,
    xhr,
    utils,
    messages
) {

    return declare(_PopupView, {
        size:  "sm",
        _model: null,

        init: function () {
            var self = this;
            self._model = getStateful({
                password: ""
            });

            return [
                ['aps/Panel', [
                    ['aps/FieldSet', [
                        ['aps/Password', {
                            id: this.genId('password'),
                            label: _('New Password'),
                            value: at(self._model, "password"),
                            required: true,
                            gridSize: "md-12 xs-12",
                            passwordVisible: true,
                            constraints: {
                                minimumLength: 8,
                                maximumLength: 16
                            },
                            generator: utils.passwordGenerator,
                            extraValidator: function (value) {
                                var res = utils.validatePassword(value);
                                if (res === true) {
                                    return true;
                                }
                                else {
                                    this.set("invalidMessage", _(res));
                                    return false;
                                }
                            }
                        }]
                    ]]
                ]]
            ];
        },
        onShow: function() {
            var password = this.byId("password");
            password.generate();
        },
        onHide: function() {
            var self = this;
            self._model.set({
                password: ""
            });
        },
        onCancel: function() {
            this.cancel();
        },
        onSubmit: function() {
            var self = this;
            if (!self.validate()) {
                aps.apsc.cancelProcessing();
                return;
            }

            var user = aps.context.params.enduser;
            xhr("/aps/2/resources/" + user.aps.id + "/changePassword", {
                method: "POST",
                headers: { "Content-Type": "application/json" },
                data: JSON.stringify(getPlainValue(self._model))
            }).then(function () {
                self.submit();
            }, messages.displayError);
        }
    });
});

