/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

define([
    "aps/Memory",
    "aps/_View",
    "aps/xhr",
    "aps/FieldSet",
    "dojo/_base/declare",
    "dijit/registry",
    "dojox/mvc/at",
    "dojox/mvc/getPlainValue",
    "dojox/mvc/getStateful",
    "./../../../common",
    "./../../../messages",
    "./../../../wizardData"
], function (
    Memory,
    _View,
    xhr,
    FieldSet,
    declare,
    registry,
    at,
    getPlainValue,
    getStateful,
    common,
    messages,
    wizardData
) {

    return declare(_View, {
        _admin: null,
        _adminModel: null,
        _tenant: null,
        _administratorId: null,
        _isInitialized: false,
        _initialize: function () {
            var self = this;
            return xhr.get("/aps/2/resources/" + self._tenant.aps.id + "/administrators/" + self._administratorId).then(function (response) {
                self._admin = response;
                self._adminModel.set({
                    login: response.login,
                    email: response.email,
                    firstName: response.firstName,
                    lastName: response.lastName
                });
                aps.apsc.hideLoading();
            }, messages.displayError);
        },
        init: function () {
            var self = this,
                enableOptions = [
                {value: "1", label: _("Enabled")},
                {value: "0", label: _("Disabled")}
            ];
            self._adminModel = getStateful({});

            return [
                ["aps/Panel", [
                    ["aps/FieldSet", {title: _("General information")}, [
                        ["aps/FieldSet",[
                            ["aps/Output", {
                                id: self.genId("login"),
                                label: _("Login"),
                                gridSize: "md-6 xs-12",
                                value: at(self._adminModel, "login")
                            }],
                            ["aps/TextBox", {
                                id: self.genId("email"),
                                label: _("Email"),
                                gridSize: "md-6 xs-12",
                                value: at(self._adminModel, "email"),
                                required: true,
                                trim: true,
                                pattern: '^[^\\s@]+@[^\\s@]+\\.[^\\s@.]+$',
                                invalidMessage: _('Please enter a valid email.')
                            }]
                        ]]
                    ]],
                    ["aps/FieldSet", {title: _("Optional")}, [
                        ["aps/FieldSet",[
                            ["aps/TextBox", {
                                id: self.genId("first_name"),
                                label: _("First name"),
                                required: false,
                                optionalText: "",
                                trim: true,
                                gridSize: "md-6 xs-12",
                                value: at(self._adminModel, "firstName")
                            }],
                            ["aps/TextBox", {
                                id: self.genId("last_name"),
                                label: _("Last name"),
                                required: false,
                                optionalText: "",
                                trim: true,
                                gridSize: "md-6 xs-12",
                                value: at(self._adminModel, "lastName")
                            }]
                        ]]
                    ]]
                ]]
            ];
        },
        onHide: function () {
            messages.removeAll();
        },
        onContext: function (context) {
            var self = this;
            self._tenant = context.vars.tenant;
            self._administratorId = aps.context.params.id;
            self._initialize();
        },
        onSubmit: function () {
            var self = this,
                tenant = self._tenant,
                adminModel = self._adminModel,
                admin = self._admin;

            if (!self.validate()) {
                aps.apsc.cancelProcessing();
                return;
            }

            xhr("/aps/2/resources/" + tenant.aps.id + "/administrators/" + self._administratorId, {
                method: "PUT",
                query: {
                    datacenterId: ''
                },
                data: JSON.stringify(getPlainValue(adminModel)),
                headers: {"Content-Type": "application/json"}
            }).then(function () {
                if (admin.status != common.STATUS.INACTIVE && admin.email !== adminModel.email) {
                    var message = {
                        text : _("The confirmation message has been sent to email '{0}'.").replace("{0}", adminModel.email),
                        type : "info"
                    };
                    wizardData.setWizardData({message: message}, 'nextcp-ccp-partner');
                }
                aps.apsc.gotoView("nextcp-ccp-partner");
            }, messages.displayError);
        }
    });
});
