/**
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

define([
    "dojo/_base/declare",
    "aps/Container",
    "aps/Grid",
    "aps/FieldSet",
    "aps/Memory",
    "./base/Output",
    "./base/Status",
    "./../../uomConverter",
    "./../../common"
], function (
    declare,
    Container,
    Grid,
    FieldSet,
    Memory,
    Output,
    Status,
    uomConverter,
    common
) {
    var statusInfo = {
        updating: {"label": _("UPDATING"), "type": "default", isLoad: true},
        deleting: {"label": _("DELETING"), "type": "danger", isLoad: true},
        notAssigned: {"label": _("NOT ASSIGNED"), "type": "default", isLoad: false},
        notActivated: {"label": _("NOT ACTIVATED"), "type": "warning", isLoad: false},
        activating: {"label": _("ACTIVATING"), "type": "warning", isLoad: true, useIcon: false},
        activated: {"label": _("ACTIVATED"), "type": "success", isLoad: false},
        disabled: {"label": _("DISABLED"), "type": "default", isLoad: true}
    };

    function createStatus(statusName) {
        return new Status({
            useIcon: false,
            gridSize: 'xs-12',
            status: statusName,
            statusInfo: statusInfo
        });
    }

    function createResourceUsageOutput(title, value) {
        return new Output({
            content: '<span title="${title}">${value}</span>',
            title: title,
            value: value
        });
    }

    function createResourceUsage(activated, backupStatistic) {
        var fieldSet = new FieldSet(),
            counters = common.getAvailableCountersForArea("quota_list_view_ccpv2");

        counters.forEach(function (counter) {
            if (backupStatistic[counter.name] && backupStatistic[counter.name].limit) {
                fieldSet.addChild(createResourceUsageOutput(
                    counter.label,
                    activated ? prepareStorageUsageStats(
                        backupStatistic[counter.name].usage,
                        backupStatistic[counter.name].limit
                    ) : _('N/A')
                ));
            }
        });

        return fieldSet;
    }

    function prepareUsageStats(value, limit) {
        var usageStats = (value > 0) ? value : 0;
        if (limit >= 0) {
            return usageStats + ' / ' + limit;
        }
        return usageStats;
    }

    function prepareStorageUsageStats(usage, limit) {
        if (limit === 0) {
            return _('None');
        }
        var usageSize = uomConverter.convertByteToMajorityUnit(usage);
        if (limit < 0) {
            return usageSize.value + ' ' + uomConverter.getUnitName(usageSize.unit);
        }
        var limitSize = uomConverter.convertByteToMajorityUnit(limit);
        return usageSize.value + ' ' + uomConverter.getUnitName(usageSize.unit) + ' / ' + limitSize.value + ' ' + uomConverter.getUnitName(limitSize.unit);
    }

    function isUserActivated(user) {
        return user.backupUserStatus === "activated";
    }

    return declare(Container, {
        users: [],
        gridSize: 'xs-12',
        style: "padding: 0px;",

        _setUsersAttr: function (val) {
            var userStore = new Memory({data: val, idProperty: "aps.id"});
            var layout = [
                {
                    "field": "backupUserStatus",
                    "escapeHTML": false,
                    renderCell: function (row, data) {
                        return createStatus(data);
                    }
                },
                {
                    "type": "resourceName",
                    "field": "displayName"
                },
                {
                    "field": "login"
                },
                {
                    "escapeHTML": false,
                    "field": "backupUserStatistic",
                    renderCell: function (row, data) {
                        return createResourceUsage(isUserActivated(row) && data, data);
                    }
                }
            ];

            var grid = new Grid({
                gridSize: 'xs-12',
                style: "padding: 0px;",
                columns: layout,
                store: userStore,
                apsResourceViewId: 'http://www.parallels.com/ccp-users#viewUser'
            });

            var container = new Container({
                title: _("Service users"),
                gridSize: 'xs-12',
                style: "padding: 0px;"
            });
            container.addChild(grid);

            this.removeAll();
            this.addChild(container);

            this.users = val;
        }
    });
});

