/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

require([
    "aps/load",
    "aps/Output",
    "aps/ResourceStore",
    "aps/xhr",
    "dijit/registry",
    "dojo/_base/array",
    "./js/common.js",
    "./js/messages.js"
], function (
    load,
    Output,
    Store,
    xhr,
    registry,
    arr,
    common,
    messages) {
    var datacentersStore = new Store({
        target: "/aps/2/resources/" + aps.context.vars.globals.aps.id + "/datacenters"
    });

    load(["aps/PageContainer", {id: "apsPageContainer"}, [
        ["aps/Output", {
            id: common.genId('output'),
            'class': 'acronis-description',
            content: _('Click <b>New</b> button to specify credentials for your Acronis Cyber Cloud partner account.')
        }],
        ["aps/Grid", {
            id: "datacenters_grid",
            selectionMode: "multiple",
            apsResourceViewId: common.getRelatedViewId('view'),
            sort: {
                attribute: "name"
            },
            showPaging: true,
            columns: [
                {field: "id", name: _("ID"), type: "resourceName", filter: {title: _("ID")}},
                {field: "name", name: _("Name"), type: "resourceName", filter: {title: _("Name")}},
                {field: "login", name: _("Login"), filter: {title: _("Login")}},
                {
                    field: "id", name: _("Subscriptions count"),
                    renderCell: function (row) {
                        var output = new Output({id: common.genId('output'), value: _("Counting...")});
                        xhr.get("/aps/2/resources/" + row.aps.id + "/info").then(
                            function (response) {
                                if (typeof response.subscriptionCount != "undefined" && response.subscriptionCount != null) {
                                    output.set('value', response.subscriptionCount);
                                }
                            }, messages.displayError);

                        return output;
                    }
                }
            ],
            store: datacentersStore
        }, [
            ["aps/Toolbar", {id: "datacenters_toolbar"}, [
                ["aps/ToolbarButton", {
                    id: "datacenters_new",
                    iconClass: "sb-add-new",
                    label: _("New")
                }],
                ["aps/ToolbarButton", {
                    id: "datacenters_delete",
                    iconClass: "sb-delete",
                    label: _("Delete"),
                    requireItems: true
                }]
            ]]
        ]]
    ]]).then(function () {

        registry.byId("datacenters_new").on("click", function () {
            aps.apsc.gotoView(common.getRelatedViewId('new'));
        });

        registry.byId("datacenters_delete").on("click", function () {
            var btn = this,
                grid = registry.byId("datacenters_grid"),
                sel = grid.get("selectionArray"),
                counter = sel.length;

            if (!confirm(_("Are you sure that you want to delete the following Datacenters: {0}?").replace("{0}", counter))) {
                btn.cancel();
                return;
            }

            messages.removeAll();

            arr.forEach(sel, function (id) {
                console.log("Deleting the Datacenter with ID '{0}'...".replace("{0}", id));

                datacentersStore.remove(id).then(function () {
                    console.log("The Datacenter with ID '{0}' has been deleted.".replace("{0}", id));
                    sel.splice(sel.indexOf(id), 1);
                    grid.refresh();
                    if (--counter === 0) {
                        btn.cancel();
                    }
                }, function (err) {
                    messages.displayErrorAndGo(err);
                    if (--counter === 0) {
                        btn.cancel();
                    }
                });
            });
        });
    }, messages.displayError);
});
