/**
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

require([
    "dijit/registry",
    "aps/load",
    "aps/xhr",
    "./js/common.js",
    "./js/messages.js",
    "./js/testConnection.js"
], function (
    registry,
    load,
    xhr,
    common,
    messages,
    testConnection
) {
    var datacenter = aps.context.vars.datacenter;

    var widgets = ["aps/PageContainer", {id: "apsPageContainer"}, [
        ["aps/FieldSet", {id: common.genId('fieldset'), title: _("General")}, [
            ["aps/Output", {
                id: "name",
                label: _("Name"),
                value: datacenter.name
            }],
            ["aps/Output", {id: "url", label: _("URL"), value: datacenter.url}],
            ["aps/Output", {id: "login", label: _("Login"), value: datacenter.login}],
            ["aps/Output", {id: "password", label: _("Password"), value: "**********"}]
        ]],
        ["aps/FieldSet", {
            title: true,
            id: "testConnectionResults",
            visible: false,
            showLabels: false
        }],
        ["aps/Container", {id: common.genId('container'), title: true}, [
            ["aps/Button", {
                id: common.genId('button'),
                title: _('Edit'),
                isDefault: true,
                onClick: function () {
                    aps.apsc.gotoView(common.getRelatedViewId('edit'), datacenter.aps.id);
                }
            }],
            ["aps/Button", {
                id: common.genId('button'),
                title: _('Back'),
                onClick: function () {
                    aps.apsc.gotoView(common.getRelatedViewId('list'));
                }
            }],
            ["aps/Button", {
                id: common.genId('button'),
                title: _('Test connection'),
                onClick: function () {
                    var self = this,
                        xhrRequest = {
                            url: "/aps/2/resources/" + datacenter.aps.id + "/check_connection",
                            options: {
                                method: "POST",
                                headers: {"Content-Type": "application/json"},
                                data: JSON.stringify({})
                            }
                        },
                        testCase = [
                            {title: _('Verifying connection to Acronis Cyber Cloud'), types: [1]}, // 2, 3
                            {title: _('Verifying credentials to Acronis Cyber Cloud'), types: [4]},
                            {title: _('Verifying connection to Odin Automation Open API'), types: [5, 6]}
                        ],
                        results = registry.byId('testConnectionResults'),
                        callback = function () {
                            self.cancel();
                        };
                    testConnection(xhrRequest, testCase, results).then(callback, callback);
                }
            }]

        ]]

    ]];
    load(widgets);

});