/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

require([
    "aps/Button",
    "aps/Container",
    "aps/load",
    "aps/Memory",
    "aps/xhr",
    "dijit/registry",
    "dojo/promise/all",
    "./js/common.js",
    "./js/messages.js",
    "./js/wizardData.js",
    "./js/tags.js"
], function (
    Button,
    Container,
    load,
    Memory,
    xhr,
    registry,
    all,
    common,
    messages,
    wizardData,
    tags
) {
    var globals = aps.context.vars.globals;

    function fetchFirstLevelResellers() {
        return xhr.get("/aps/2/resources/" + globals.aps.id + "/firstLevelResellers");
    }

    function goToConfigureForReseller(reseller) {
        var viewId = common.getRelatedViewId('configuration');
        wizardData.setWizardData(reseller, viewId);
        aps.apsc.gotoView(viewId);
    }

    var columns = [
        {
            field: "accountId",
            name: _("Reseller ID"),
            'class': 'vcenter'
        },
        {
            field: "name",
            name: _("Reseller Name"),
            'class': 'vcenter'
        },
        {
            name: _("Discount ID"),
            'class': 'vcenter',
            sortable: false,
            escapeHTML: false,
            renderCell: function (reseller) {
                return reseller.discountId ? reseller.discountId : '';
            }
        },
        {
            name: _("Discount Name"),
            'class': 'vcenter',
            sortable: false,
            escapeHTML: false,
            renderCell: function (reseller) {
                return reseller.discount ? reseller.discount.name : '';
            }
        },
        {
            name: _("Discount Status"),
            sortable: false,
            escapeHTML: false,
            renderCell: function (reseller) {
                if (!reseller.discount) {
                    if (reseller.discountId) {
                        return tags.img("images/statuses/warning24.png") + ' ' + _("Configured but not found");
                    }
                    return tags.img("images/statuses/warning24.png") + ' ' + _("Not configured");
                }
                if (!reseller.discount.isAllowedForFirstLevelReseller) {
                    return tags.img("images/statuses/warning24.png") + ' ' + _("Configured but is incorrect");
                }
                return tags.img("images/statuses/ok24.png") + ' ' + _("Configured");
            }
        },
        {
            name: _("Actions"),
            sortable: false,
            escapeHTML: false,
            renderCell: function (reseller) {
                if (!reseller.discountId) {
                    return new Button({
                        iconClass: "sb-modify-selected",
                        label: _("Configure"),
                        onClick: function () {
                            goToConfigureForReseller(reseller);
                        }
                    });
                }

                var editButton = new Button({
                    iconClass: "sb-modify-selected",
                    label: _("Edit"),
                    onClick: function () {
                        goToConfigureForReseller(reseller);
                    }
                });
                var deleteButton = new Button({
                    iconClass: "sb-remove-selected",
                    label: _("Remove"),
                    onClick: function () {
                        var self = this;
                        xhr("/aps/2/resources/" + globals.aps.id + "/reseller/" + reseller.accountId + "/discount", {
                            method: "DELETE"
                        }).then(
                            function () {
                                fetchFirstLevelResellers().then(function (firstLevelResellers) {
                                    var grid = registry.byId("firstLevelResellersGrid");
                                    grid.set(
                                        "store",
                                        new Memory({data: firstLevelResellers, idProperty: "accountId"})
                                    );
                                    grid.refresh();
                                    self.cancel();
                                }, function (error) {
                                    messages.displayError(error);
                                    self.cancel();
                                });
                            },
                            function (error) {
                                messages.displayError(error);
                                self.cancel();
                            }
                        );
                    }
                });
                var container = new Container();
                container.addChild(editButton);
                container.addChild(deleteButton);
                return container;
            }
        }
    ];

    var infoHtml = tags.div([
        _("On this tab you can configure a Discount for Acronis service plans for each of the top-level resellers."),
        "<br/>",
        _("Discount configured will be automatically assigned to sub-resellers (service providers) on Acronis Tier subscription provisioning, and unassigned on Acronis Tier subscription destroying."),
        "<br/>",
        _("Please make sure that the Discount is created under the proper L1 reseller, is active, has \"Discount By Account/Customer Class\" type, covers all Acronis billable resources, has 100% Discount Rate and \"For all resources\" and \"For all service plans\" options are disabled for it."),
        "<br/>",
        "<br/>"
    ].join(""));

    var widgets = ["aps/PageContainer", {id: "apsPageContainer", "class": ""}, [
        ["aps/Container", {
            id: "informationContainer",
            title: _("Information")
        }, [
            ["aps/Output", {
                id: common.genId('output'),
                escapeHTML: false,
                value: infoHtml
            }]

        ]],
        ["aps/Container", {
            id: "resellersAndDiscountsContainer",
            title: _("Resellers and Discounts")
        }, [
            ["aps/Output", {
                id: common.genId('output'),
                escapeHTML: false,
                value: tags.div([
                    tags.img("images/statuses/warning24.png"),
                    _("In case no discount is assigned to Reseller, its Sub-resellers that are using Tiered Pricing Model may be double.")
                ].join(""))
            }],
            ["aps/Grid", {
                id: "firstLevelResellersGrid",
                showPaging: false,
                pageSizeOptions: "GRID_UNLIMITED",
                columns: columns
            }]
        ]]
    ]];

    fetchFirstLevelResellers().then(function (firstLevelResellers) {
        load(widgets).then(function () {
            var grid = registry.byId("firstLevelResellersGrid");
            grid.set(
                "store",
                new Memory({data: firstLevelResellers, idProperty: "accountId"})
            );
            grid.refresh();
        });
    }, messages.displayError);
});
