/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

require([
    "aps/load",
    "aps/ResourceStore",
    "aps/xhr",
    "dijit/registry",
    "dojo/_base/array",
    "dojo/Deferred",
    "./js/common.js",
    "./js/messages.js"
], function (
    load,
    Store,
    xhr,
    registry,
    arr,
    Deferred,
    common,
    messages
) {
    function removeMinimalCommitmentTier(id) {
        var deferred = new Deferred();
        xhr("/aps/2/resources/" + id + "/unbind_resource_type", {
            method: "POST"
        }).then(function () {
            tiersStore.remove(id).then(deferred.resolve, deferred.reject);
        }, deferred.reject);
        return deferred;
    }

    var globals = aps.context.vars.globals,
        tiersStore = new Store({
            target: "/aps/2/resources/" + globals.aps.id + "/minimalCommitmentTiers"
        });

    load(["aps/PageContainer", {id: "apsPageContainer"}, [
        ["aps/Grid", {
            id: "tiers_grid",
            selectionMode: "multiple",
            apsResourceViewId: common.getRelatedViewId('view'),
            sort: {
                attribute: "name"
            },
            showPaging: true,
            columns: [
                {field: "aps.id", name: _("ID"), visible: false},
                {field: "resourceTypeId", name: _("Resource ID"), filter: {title: _("Resource ID")}},
                {field: "name", name: _("Name"), type: "resourceName", filter: {title: _("Name")}},
                {
                    field: "level", name: _("Level"), filter: {title: _("Level")},
                    renderCell: function(raw) {
                        return common.getMinimalCommitmentLevelName(raw.level);
                    }
                }
            ],
            store: tiersStore
        }, [
            ["aps/Toolbar", {id: "tiers_toolbar"}, [
                ["aps/ToolbarButton", {id: "tiers_new", iconClass: "sb-add-new", label: _("New")}],
                ["aps/ToolbarButton", {
                    id: "tiers_delete",
                    iconClass: "sb-delete",
                    label: _("Delete"),
                    requireItems: true
                }]
            ]]
        ]]
    ]]).then(function () {

        registry.byId("tiers_new").on("click", function () {
            aps.apsc.gotoView(common.getRelatedViewId('new'));
        });

        registry.byId("tiers_delete").on("click", function () {
            var btn = this,
                grid = registry.byId("tiers_grid"),
                sel = grid.get("selectionArray"),
                counter = sel.length;

            if (!confirm(_("Are you sure that you want to delete the following minimum commitment tiers: {0}?").replace("{0}", counter))) {
                btn.cancel();
                return;
            }

            messages.removeAll();

            arr.forEach(sel, function (id) {
                console.log("Deleting the minimum commitment tier with ID '{0}'...".replace("{0}", id));

                removeMinimalCommitmentTier(id).then(function () {
                    console.log("The minimum commitment tier with ID '{0}' has been deleted.".replace("{0}", id));
                    sel.splice(sel.indexOf(id), 1);
                    grid.refresh();
                    if (--counter === 0) {
                        btn.cancel();
                    }
                }, function (err) {
                    messages.displayErrorAndGo(err);
                    if (--counter === 0) {
                        btn.cancel();
                    }
                });
            });
        });
    }, messages.displayError);
});
