/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

require([
    "aps/load",
    "aps/xhr",
    "./js/common.js",
    "./js/messages.js",
    "./js/wizardData.js"
], function (
    load,
    xhr,
    common,
    messages,
    wizardData
) {
    var tenant = aps.context.vars.tenant,
        data = wizardData.getWizardData(common.getRelatedViewId('view')),
        adminId = data && data.adminId ? data.adminId : null,
        datacenterId = data && data.datacenterId ? data.datacenterId : null,
        showDatacenters = data && data.showDatacenters ? data.showDatacenters : false;

    function getUserStatus(status) {
        var content;
        switch (status) {
            case -1:
                content = '<img src=images/user_statuses/ico_state_off_16px.png> ' + _("Not activated");
                break;
            case 0:
                content = '<img src=images/user_statuses/ico_state_off_16px.png> ' + _("Disabled");
                break;
            case 1:
                content = '<img src=images/user_statuses/ico_state_on_16px.png> ' + _("Enabled");
                break;
        }
        return content;
    }

    xhr.get(
        "/aps/2/resources/" + tenant.aps.id + "/administrators/" + adminId,
        {query: {datacenterId: datacenterId}}
    ).then(function (admin) {
        load(["aps/PageContainer", {id: "apsPageContainer"}, [
            ["aps/FieldSet", {title: _("General")}, [
                ["aps/Output", {
                    label: _("Datacenter"),
                    value: admin.datacenterName,
                    visible: showDatacenters
                }],
                ["aps/Output", {
                    label: _("Login"),
                    value: admin.login
                }],
                ["aps/Output", {
                    label: _("Email"),
                    value: admin.email
                }],
                ["aps/Output", {
                    label: _("First name"),
                    value: admin.firstName
                }],
                ["aps/Output", {
                    label: _("Last name"),
                    value: admin.lastName
                }],
                ["aps/Output", {
                    label: _("Status"),
                    escapeHTML: false,
                    value: getUserStatus(admin.status)
                }]
            ]],
            ["aps/FieldSet", {title: _("Notifications")}, [
                ["aps/FieldSet", {
                    label: "MANAGEMENT PORTAL",
                    class: 'acronis-notifications-section-title',
                    title: false
                }],
                ["aps/Output", {
                    label: _('Quota overuse notifications'),
                    value: common.printNotification(admin.notifications, 'quota')
                }],
                ["aps/Output", {
                    label: _('Scheduled usage reports'),
                    value: common.printNotification(admin.notifications, 'reports')
                }],
                ["aps/Output", {
                    class: 'space-before-element'
                }],
                ["aps/FieldSet", {
                    label: "CYBER PROTECTION",
                    class: 'acronis-notifications-section-title',
                    title: false
                }],
                ["aps/Output", {
                    label: _('Failure notifications'),
                    value: common.printNotification(admin.notifications, 'backup_error')
                }],
                ["aps/Output", {
                    label: _('Warning notifications'),
                    value: common.printNotification(admin.notifications, 'backup_warning')
                }],
                ["aps/Output", {
                    label: _('Success notifications'),
                    value: common.printNotification(admin.notifications, 'backup_info')
                }],
                ["aps/Output", {
                    label: _('Daily recap about active alerts'),
                    value: common.printNotification(admin.notifications, 'backup_daily_report')
                }]
            ]],
            ["aps/FieldSet", {title: true}],
            ["aps/Container", {id: "buttons"}, [
                ["aps/Button", {
                    title: _("Edit"),
                    onClick: function () {
                        var viewId = common.getRelatedViewId('edit');
                        wizardData.setWizardData({
                            adminId: admin.id,
                            datacenterId: admin.datacenterId,
                            showDatacenters: showDatacenters
                        }, viewId);
                        aps.apsc.gotoView(viewId);
                    }
                }],
                ["aps/Button", {
                    title: _("Back"),
                    onClick: function () {
                        aps.apsc.gotoView(common.getRelatedViewId('list'));
                    }
                }]
            ]]
        ]]).then(function () {
            var data = wizardData.getWizardData(common.getRelatedViewId('view'));
            if (data && data.newAdminEmail && admin.status == common.USER_STATUS.ACTIVE) {
                messages.displayMessage(_("The confirmation message has been sent to email '{0}'.").replace("{0}", data.newAdminEmail), "info");
                wizardData.resetWizardData(common.getRelatedViewId('view'));
            }
        });
    }, messages.displayError);
});
