/*
 * @Copyright © 2002-2018 Acronis International GmbH. All rights reserved
 */

define([], function () {
    function generate(tag, content, attrs) {
        attrs = attrs || {};
        var attrsList = [];
        for (var k in attrs) {
            if (!attrs.hasOwnProperty(k)) continue;
            attrsList.push(k + '=' + attrs[k]);
        }
        return '<' + tag + (attrsList.length ? ' ' + attrsList.join(' ') : '') + '>' + content + '</' + tag + '>';
    }

    return {
        icon: function (iconClass, size) {
            var result = '<i class="' + iconClass + '"></i>';
            if (size !== undefined) {
                result = '<div class="acronis-icon-wrapper acronis-size-' + size + '">' + result + '</div>';
            }

            return result;
        },

        div: function (content, attrs) {
            return generate('div', content, attrs);
        },

        ul: function (items) {
            var self = this;
            return generate('ul', items.map(function (item) {
                return self.li(item);
            }).join(''));
        },

        li: function (content) {
            return generate('li', content);
        },

        a: function (href, content, attrs) {
            attrs = attrs || {};
            attrs.href = href;
            return generate('a', content, attrs);
        },

        img: function (src) {
            return '<img src=' + src + '>';
        },

        h: function (size, content) {
            return generate('h' + size, content);
        },

        strong: function (content, attrs) {
            return generate('strong', content, attrs);
        },

        br: function () {
            return '<br/>';
        }
    };
});
