/*
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */

/*
 * Methods to work with messages.
 */
define([
    "dojo/_base/lang",
    "dojo/Deferred",
    "aps/xhr",
    "aps/Output",
    "./js/messages.js"
], function (
    lang,
    Deferred,
    xhr,
    Output,
    messages
) {
    
    function runTestType(request, type, container) {
        var deferred = new Deferred();
        xhr(request.url, lang.mixin(request.options, {query: {type: type}})).then(function (response) {
            var description = _(response.description.message, response.description.keys),
                error = response.error.code ? response.error.code + ' - ' + response.error.message : response.error.message;
            container.addChild(new Output({
                content: response.success ?
                    "<span style='color: green'>${description}...${result}</span>" :
                    "<span style='color: red'>${description} (${error})...${result}</span>",
                description: description,
                error: error,
                result: response.success ? _('SUCCESS') : _('FAIL')
            }));
            deferred.resolve();
        }, function (response) {
            var error = messages.parseError(response);
            container.addChild(new Output({
                content: "<span style='color: red'>${error}</span>",
                error: error
            }));
            deferred.resolve();
        });
        return deferred;
    }

    function runTestCase(request, testCase, container) {
        var deferred = new Deferred();

        xhr(request.url, lang.mixin(request.options, {query: {type: 0}})).then(function (response) {
            var promise = deferred.then(function () {
                container.removeAll();
                container.set("visible", true);

                container.addChild(new Output({
                    content: '<h3>${value} (${host}):</h3>',
                    value: _('Test connection from endpoint'),
                    host: response.host
                }));
            });

            testCase.forEach(function (test) {
                promise = promise.then(function () {
                    container.addChild(new Output({
                        content: '<b>${value}:</b>',
                        value: test.title
                    }));
                });

                test.types.forEach(function (type) {
                    promise = promise.then(function () {
                        return runTestType(request, type, container).promise;
                    });
                });
            });

            promise.then(function () {
                container.addChild(new Output({
                    content: '<b>${value}</b>',
                    value: _('The check has completed.')
                }));
            });
            deferred.resolve();
        }, function (error) {
            deferred.reject();
            messages.displayError(error);
        });

        return deferred.promise;
    }

    return runTestCase;
});
