<?php
/**
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

namespace Acronis\App\CloudApi;

use Acronis\Cloud\Client\ApiException;
use Acronis\Cloud\Client\HttpException;
use Acronis\Cloud\Client\Model\AccessPolicies\AccessPolicy;
use Acronis\Cloud\Client\Model\Applications\Application;
use Acronis\Cloud\Client\Model\Infra\Infra;
use Acronis\Cloud\Client\Model\OfferingItems\OfferingItemOutput;
use Acronis\Cloud\Client\Model\Reports\Report;
use Acronis\Cloud\Client\Model\Reports\Stored\StoredReportParamsItems;
use Acronis\Cloud\Client\Model\Tenants\OfferingItem;
use Acronis\Cloud\Client\Model\Tenants\Tenant;
use Acronis\Cloud\Client\Model\Usages\UsageOutput;
use Acronis\Cloud\Client\Model\Users\User;
use Acronis\Cloud\Client\Model\Users\UserPost;
use Acronis\Cloud\Client\Model\Users\UserPut;

interface ApiInterface
{
    const NULL_UUID = '00000000-0000-0000-0000-000000000000';

    const EDITION_ANY = '*';

    const EDITION_ADV = 'advanced';
    const EDITION_P_ADV = 'cyber_protect_adv';
    const EDITION_DRE = 'disaster_recovery';
    const EDITION_P_DRE = 'cyber_protect_dre';
    const EDITION_P = 'cyber_protect_std';
    const EDITION_STD = 'standard';

    const APPLICATION_TYPE_BACKUP = 'backup';
    const APPLICATION_TYPE_FILES_CLOUD = 'files_cloud';
    const APPLICATION_TYPE_HYPER_CONVERGED_INFRASTRUCTURE = 'hci';
    const APPLICATION_TYPE_NOTARY = 'notary';
    const APPLICATION_TYPE_PHYSICAL_DATA_SHIPPING = 'physical_data_shipping';
    const APPLICATION_TYPE_PLATFORM = 'platform';

    const OFFERING_ITEM_TYPE_COUNT = 'count';
    const OFFERING_ITEM_TYPE_INFRA = 'infra';
    const OFFERING_ITEM_TYPE_FEATURE = 'feature';

    // Backup
    const OFFERING_ITEM_STORAGE = 'storage';
    const OFFERING_ITEM_LOCAL_STORAGE = 'local_storage';
    const OFFERING_ITEM_WORKSTATIONS = 'workstations';
    const OFFERING_ITEM_SERVERS = 'servers';
    const OFFERING_ITEM_WEB_HOSTING_SERVERS = 'web_hosting_servers';
    const OFFERING_ITEM_VMS = 'vms';
    const OFFERING_ITEM_MOBILES = 'mobiles';
    const OFFERING_ITEM_WEBSITES = 'websites';
    const OFFERING_ITEM_MAILBOXES = 'mailboxes';
    const OFFERING_ITEM_MAILBOX_INSTANCE_SIZE = 'mailbox_instance_size';
    const OFFERING_ITEM_O365_MAILBOXES = 'o365_mailboxes';
    const OFFERING_ITEM_O365_ONEDRIVE = 'o365_onedrive';
    const OFFERING_ITEM_ADV_GOOGLE_DRIVE = 'adv_google_drive';
    const OFFERING_ITEM_ADV_GOOGLE_MAIL = 'adv_google_mail';
    const OFFERING_ITEM_ADV_GOOGLE_TEAM_DRIVE = 'adv_google_team_drive';
    const OFFERING_ITEM_ADV_GSUITE_SEATS = 'adv_gsuite_seats';
    const OFFERING_ITEM_ADV_O365_SEATS = 'adv_o365_seats';
    const OFFERING_ITEM_ADV_MOBILES = 'adv_mobiles';
    const OFFERING_ITEM_ADV_O365_MAILBOXES = 'adv_o365_mailboxes';
    const OFFERING_ITEM_ADV_O365_ONEDRIVE = 'adv_o365_onedrive';
    const OFFERING_ITEM_ADV_O365_SHAREPOINT_SITES = 'adv_o365_sharepoint_sites';
    const OFFERING_ITEM_ADV_SERVERS = 'adv_servers';
    const OFFERING_ITEM_ADV_STORAGE = 'adv_storage';
    const OFFERING_ITEM_ADV_VMS = 'adv_vms';
    const OFFERING_ITEM_ADV_WEB_HOSTING_SERVERS = 'adv_web_hosting_servers';
    const OFFERING_ITEM_ADV_WEBSITES = 'adv_websites';
    const OFFERING_ITEM_ADV_WORKSTATIONS = 'adv_workstations';
    const OFFERING_ITEM_P_ADV_GOOGLE_DRIVE = 'p_adv_google_drive';
    const OFFERING_ITEM_P_ADV_GOOGLE_MAIL = 'p_adv_google_mail';
    const OFFERING_ITEM_P_ADV_GOOGLE_TEAM_DRIVE = 'p_adv_google_team_drive';
    const OFFERING_ITEM_P_ADV_GSUITE_SEATS = 'p_adv_gsuite_seats';
    const OFFERING_ITEM_P_ADV_O365_SEATS = 'p_adv_o365_seats';
    const OFFERING_ITEM_P_ADV_MOBILES = 'p_adv_mobiles';
    const OFFERING_ITEM_P_ADV_O365_MAILBOXES = 'p_adv_o365_mailboxes';
    const OFFERING_ITEM_P_ADV_O365_ONEDRIVE = 'p_adv_o365_onedrive';
    const OFFERING_ITEM_P_ADV_O365_SHAREPOINT_SITES = 'p_adv_o365_sharepoint_sites';
    const OFFERING_ITEM_P_ADV_SERVERS = 'p_adv_servers';
    const OFFERING_ITEM_P_ADV_STORAGE = 'p_adv_storage';
    const OFFERING_ITEM_P_ADV_VMS = 'p_adv_vms';
    const OFFERING_ITEM_P_ADV_WEB_HOSTING_SERVERS = 'p_adv_web_hosting_servers';
    const OFFERING_ITEM_P_ADV_WEBSITES = 'p_adv_websites';
    const OFFERING_ITEM_P_ADV_WORKSTATIONS = 'p_adv_workstations';
    const OFFERING_ITEM_P_DRE_COMPUTE_POINTS = 'p_dre_compute_points';
    const OFFERING_ITEM_P_DRE_DR_CLOUD_SERVERS = 'p_dre_dr_cloud_servers';
    const OFFERING_ITEM_P_DRE_DR_INTERNET_ACCESS = 'p_dre_dr_internet_access';
    const OFFERING_ITEM_P_DRE_GOOGLE_DRIVE = 'p_dre_google_drive';
    const OFFERING_ITEM_P_DRE_GOOGLE_MAIL = 'p_dre_google_mail';
    const OFFERING_ITEM_P_DRE_GOOGLE_TEAM_DRIVE = 'p_dre_google_team_drive';
    const OFFERING_ITEM_P_DRE_GSUITE_SEATS = 'p_dre_gsuite_seats';
    const OFFERING_ITEM_P_DRE_O365_SEATS = 'p_dre_o365_seats';
    const OFFERING_ITEM_P_DRE_MOBILES = 'p_dre_mobiles';
    const OFFERING_ITEM_P_DRE_DR_STORAGE = 'p_dre_dr_storage';
    const OFFERING_ITEM_P_DRE_O365_MAILBOXES = 'p_dre_o365_mailboxes';
    const OFFERING_ITEM_P_DRE_O365_ONEDRIVE = 'p_dre_o365_onedrive';
    const OFFERING_ITEM_P_DRE_O365_SHAREPOINT_SITES = 'p_dre_o365_sharepoint_sites';
    const OFFERING_ITEM_P_DRE_PUBLIC_IPS = 'p_dre_public_ips';
    const OFFERING_ITEM_P_DRE_SERVERS = 'p_dre_servers';
    const OFFERING_ITEM_P_DRE_STORAGE = 'p_dre_storage';
    const OFFERING_ITEM_P_DRE_VMS = 'p_dre_vms';
    const OFFERING_ITEM_P_DRE_WEB_HOSTING_SERVERS = 'p_dre_web_hosting_servers';
    const OFFERING_ITEM_P_DRE_WEBSITES = 'p_dre_websites';
    const OFFERING_ITEM_P_DRE_WORKSTATIONS = 'p_dre_workstations';
    const OFFERING_ITEM_P_GOOGLE_DRIVE = 'p_google_drive';
    const OFFERING_ITEM_P_GOOGLE_MAIL = 'p_google_mail';
    const OFFERING_ITEM_P_GOOGLE_TEAM_DRIVE = 'p_google_team_drive';
    const OFFERING_ITEM_P_GSUITE_SEATS = 'p_gsuite_seats';
    const OFFERING_ITEM_P_O365_SEATS = 'p_o365_seats';
    const OFFERING_ITEM_P_MOBILES = 'p_mobiles';
    const OFFERING_ITEM_P_O365_MAILBOXES = 'p_o365_mailboxes';
    const OFFERING_ITEM_P_O365_ONEDRIVE = 'p_o365_onedrive';
    const OFFERING_ITEM_P_O365_SHAREPOINT_SITES = 'p_o365_sharepoint_sites';
    const OFFERING_ITEM_P_SERVERS = 'p_servers';
    const OFFERING_ITEM_P_STORAGE = 'p_storage';
    const OFFERING_ITEM_P_VMS = 'p_vms';
    const OFFERING_ITEM_P_WEB_HOSTING_SERVERS = 'p_web_hosting_servers';
    const OFFERING_ITEM_P_WEBSITES = 'p_websites';
    const OFFERING_ITEM_P_WORKSTATIONS = 'p_workstations';
    const OFFERING_ITEM_DRE_COMPUTE_POINTS = 'dre_compute_points';
    const OFFERING_ITEM_DRE_DR_CLOUD_SERVERS = 'dre_dr_cloud_servers';
    const OFFERING_ITEM_DRE_DR_INTERNET_ACCESS = 'dre_dr_internet_access';
    const OFFERING_ITEM_DRE_GOOGLE_DRIVE = 'dre_google_drive';
    const OFFERING_ITEM_DRE_GOOGLE_MAIL = 'dre_google_mail';
    const OFFERING_ITEM_DRE_GOOGLE_TEAM_DRIVE = 'dre_google_team_drive';
    const OFFERING_ITEM_DRE_GSUITE_SEATS = 'dre_gsuite_seats';
    const OFFERING_ITEM_DRE_O365_SEATS = 'dre_o365_seats';
    const OFFERING_ITEM_DRE_MOBILES = 'dre_mobiles';
    const OFFERING_ITEM_DRE_DR_STORAGE = 'dre_dr_storage';
    const OFFERING_ITEM_DRE_O365_MAILBOXES = 'dre_o365_mailboxes';
    const OFFERING_ITEM_DRE_O365_ONEDRIVE = 'dre_o365_onedrive';
    const OFFERING_ITEM_DRE_O365_SHAREPOINT_SITES = 'dre_o365_sharepoint_sites';
    const OFFERING_ITEM_DRE_PUBLIC_IPS = 'dre_public_ips';
    const OFFERING_ITEM_DRE_SERVERS = 'dre_servers';
    const OFFERING_ITEM_DRE_STORAGE = 'dre_storage';
    const OFFERING_ITEM_DRE_VMS = 'dre_vms';
    const OFFERING_ITEM_DRE_WEB_HOSTING_SERVERS = 'dre_web_hosting_servers';
    const OFFERING_ITEM_DRE_WEBSITES = 'dre_websites';
    const OFFERING_ITEM_DRE_WORKSTATIONS = 'dre_workstations';
    const OFFERING_ITEM_GSUITE_SEATS = 'gsuite_seats';
    const OFFERING_ITEM_GOOGLE_TEAM_DRIVE = 'google_team_drive';
    const OFFERING_ITEM_GOOGLE_MAIL = 'google_mail';
    const OFFERING_ITEM_GOOGLE_DRIVE = 'google_drive';
    const OFFERING_ITEM_ADV_O365_TEAMS = 'adv_o365_teams';
    const OFFERING_ITEM_P_ADV_O365_TEAMS = 'p_adv_o365_teams';
    const OFFERING_ITEM_P_DRE_O365_TEAMS = 'p_dre_o365_teams';
    const OFFERING_ITEM_P_O365_TEAMS = 'p_o365_teams';
    const OFFERING_ITEM_DRE_O365_TEAMS = 'dre_o365_teams';
    const OFFERING_ITEM_O365_TEAMS = 'o365_teams';
// scripts_app_cloud_api_api_interface_constant this code is used for code generation, do not remove!
    const OFFERING_ITEM_O365_SHAREPOINT_SITES = 'o365_sharepoint_sites';

    // Disaster Recovery
    const OFFERING_ITEM_DR_STORAGE = 'dr_storage';
    const OFFERING_ITEM_COMPUTE_POINTS = 'compute_points';
    const OFFERING_ITEM_PUBLIC_IPS = 'public_ips';
    const OFFERING_ITEM_DR_CLOUD_SERVERS = 'dr_cloud_servers';
    const OFFERING_ITEM_DR_INTERNET_ACCESS = 'dr_internet_access';


    // List of all child storages offering items, can be enabled only by partners
    const OFFERING_ITEM_CHILD_STORAGES = 'child_storages';
    const OFFERING_ITEM_P_CHILD_STORAGES = 'p_child_storages';
    const OFFERING_ITEM_ADV_CHILD_STORAGES = 'adv_child_storages';
    const OFFERING_ITEM_P_ADV_CHILD_STORAGES = 'p_adv_child_storages';
    const OFFERING_ITEM_DRE_CHILD_STORAGES = 'dre_child_storages';
    const OFFERING_ITEM_P_DRE_CHILD_STORAGES = 'p_dre_child_storages';
    const OFFERING_ITEM_DR_CHILD_STORAGES = 'dr_child_storages';
    const OFFERING_ITEM_DRE_DR_CHILD_STORAGES = 'dre_dr_child_storages';
    const OFFERING_ITEM_P_DRE_DR_CHILD_STORAGES = 'p_dre_dr_child_storages';

    const OFFERING_ITEM_STATUS_ACTIVE = 1;
    const OFFERING_ITEM_STATUS_INACTIVE = 0;

    const UNLIMITED_OFFERING_ITEM_VALUE = null;

    /**
     * @return string
     */
    public function getUrl();

    /**
     * @return string
     */
    public function getLogin();

    /**
     * @return string
     */
    public function getPassword();

    /* ====== Users API ====== */

    /**
     * @return User
     */
    public function getMe();

    /**
     * Returns True if the login exists otherwise False
     *
     * @param string $login
     * @return bool
     */
    public function checkLogin($login);

    /* ====== Methods to manage users ====== */

    /**
     * @param UserPost $userBody
     * @return User
     */
    public function createUser(UserPost $userBody);

    /**
     * @param string $userId
     * @param int $version
     * @return User
     */
    public function deleteUser($userId, $version);

    /**
     * @param string $userId
     * @return User
     */
    public function getUser($userId);

    /**
     * @param string $userId
     * @param UserPut $userBody
     * @return User
     */
    public function updateUser($userId, UserPut $userBody);

    /**
     * @param $userId
     * @param AccessPolicy[] $accessPolicies
     * @return AccessPolicy[]
     */
    public function updateUserAccessPolicies($userId, array $accessPolicies);

    /* ====== Methods to manage tenants ====== */

    /**
     * @param string $tenantId
     * @return Tenant
     */
    public function getTenant($tenantId);

    /**
     * @param $tenantId
     * @param $putTenant
     * @return Tenant
     */
    public function updateTenant($tenantId, $putTenant);

    /**
     * @param $rootTenantId
     * @param $leafTenantId
     * @return string[] a list of UUIDs
     */
    public function resolveTenantPath($rootTenantId, $leafTenantId);

    /**
     * @param string $tenantId
     * @return UsageOutput[]
     */
    public function getTenantUsages($tenantId);

    /**
     * @param string $tenantId
     * @return User[]
     * @throws ApiException
     * @throws HttpException
     */
    public function getTenantUsers($tenantId);

    /* ====== Methods to manage tenant's applications ====== */

    /**
     * @return Application[]
     */
    public function getApplications();

    /**
     * @param string $type
     * @return Application|null
     */
    public function getApplicationByType($type);

    /**
     * @param string $tenantId
     * @return string[] a list of UUIDs
     */
    public function getTenantApplicationsUuids($tenantId);

    /**
     * @param $tenantId
     * @param $kind
     * @param string $edition
     * @return mixed
     */
    public function getOfferingItemsAvailableForChild($tenantId, $kind, $edition = self::EDITION_ANY);

    /**
     * @param string $tenantId
     * @param string $applicationId
     * @return bool
     */
    public function isApplicationEnabledForTenant($tenantId, $applicationId);

    /**
     * @param string $tenantId
     * @param string $applicationId
     */
    public function enableApplicationForTenant($tenantId, $applicationId);

    /**
     * @param string $tenantId
     * @param string $applicationId
     */
    public function disableApplicationForTenant($tenantId, $applicationId);

    /* ====== Methods to manage offering items ====== */

    /**
     * @param string $tenantId
     * @param string $applicationId
     * @param string $edition
     * @return OfferingItemOutput[]
     */
    public function getTenantApplicationOfferingItems($tenantId, $applicationId, $edition = '*');

    /**
     * @param string $tenantId
     * @param OfferingItem[] $offeringItems
     * @return OfferingItemOutput[]
     */
    public function updateTenantApplicationOfferingItems($tenantId, $offeringItems);

    /**
     * Recursive enable an application for a hierarchy of tenants except root tenant.
     *
     * @param string $rootTenantId
     * @param string $leafTenantId
     * @param string $applicationId
     */
    public function enableApplicationForTenantsChain($rootTenantId, $leafTenantId, $applicationId);

    /**
     * Recursive enable specified offering items with unlimited quotas for a hierarchy of tenants except root tenant.
     * Note: Enabled or not specified offering items won't be affected
     *
     * @param string $rootTenantId
     * @param string $leafTenantId
     * @param string $applicationId
     * @param OfferingItem[] $offeringItems
     */
    public function enableApplicationOfferingItemsForTenantsChain(
        $rootTenantId,
        $leafTenantId,
        $applicationId,
        array $offeringItems
    );

    /**
     * @param $applicationType
     * @return Application|null
     */
    public function getApplication($applicationType);

    /**
     * @param $userPersonalTenantId
     * @return OfferingItemOutput[]
     */
    public function getOfferingItemsAvailableForChildHashMap($userPersonalTenantId);

    /**
     * Update specified only offering items for $leafTenantId.
     * Recursive enable offering items for tenant's parent (see method enableUnlimitedOfferingItemsForTenantsChain)
     *
     * @param string $rootTenantId
     * @param string $leafTenantId
     * @param string $applicationId
     * @param OfferingItem[] $offeringItems
     */
    public function updateApplicationOfferingItemsForTenantsChain(
        $rootTenantId,
        $leafTenantId,
        $applicationId,
        array $offeringItems
    );

    /* ====== Methods to manage reports ====== */

    /**
     * @param string $reportId
     * @return StoredReportParamsItems[]
     */
    public function getStoredUsageReports($reportId);

    /**
     * @param string $reportId
     * @param string $storedReportId
     * @param string $destinationFile
     * @return void
     */
    public function downloadStoredUsageReportArchive($reportId, $storedReportId, $destinationFile);

    /**
     * @param string $tenantId
     * @return Report
     */
    public function orderCurrentUsageReportForAccounts($tenantId);

    /* ====== Methods to manage infra objects ====== */

    /**
     * @param string $tenantId
     * @return string[] a list of UUIDs
     */
    public function getTenantInfrasUuids($tenantId);

    /**
     * @param string[] $uuids
     * @return Infra[]
     */
    public function fetchInfras($uuids);

    /**
     * @param string $tenantId
     * @param string $capability
     * @return Infra[]
     */
    public function fetchTenantInfras($tenantId, $capability);

    /**
     * @param $rootTenantId
     * @param $leafTenantId
     * @return string[] a list of UUIDs
     */
    public function getInfrasUuidsForTenantsChain($rootTenantId, $leafTenantId);

    /**
     * @param $rootTenantId
     * @param $leafTenantId
     * @return Infra[]
     */
    public function fetchInfrasForTenantsChain($rootTenantId, $leafTenantId);
}





