<?php
/**
 * @Copyright © 2002-2018 Acronis International GmbH. All rights reserved
 */

namespace Acronis\App\Console\Command\UsageReport;

use Acronis\App\Console\Command\Loggable;
use Acronis\App\Services\UsageReportManager\UsageReportManagerAwareTrait;
use Str;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

final class Erase extends Loggable
{
    use UsageReportManagerAwareTrait;

    protected function getCommandName()
    {
        return 'usage-report:erase';
    }

    protected function getCommandDescription()
    {
        return Str::format(
            'Command for usage reports erasing, keeping only reports for last "%s" days.',
            $this->getUsageReportManager()->getReportDownloadedFilesTtlInDays()
        );
    }

    protected function getCommandHelp()
    {
        return <<<TEXT
<info>
This command cleans downloaded usage report. Reports ordered some number of days before 
(specified as "downloaded_files_ttl_in_days" in application.yaml)
would be marked with ERASED status and its downloaded .csv.gz files would be deleted. 
In the end of the execution command will remove empty folders from reports download path.
</info>
TEXT;
    }

    /* ====== Main business logic of this command ====== */

    /**
     * @param InputInterface $input
     * @param OutputInterface $output
     * @return int|null|void
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $this->getUsageReportManager()->eraseReports();
    }
}