<?php
/**
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

class Service_MspApiClient_Request_Struct_UpdateUserInfo extends Service_BaseClient_Request_Struct_Updatable
    implements Service_MspApiClient_Request_Struct_UserInfoInterface
{
    /** @var string */
    private $_email;
    /** @var string */
    private $_language;
    /** @var string */
    private $_firstName;
    /** @var string */
    private $_lastName;
    /** @var Enum_NotificationsBackup */
    private $_notificationsBackup = null;
    /** @var int */
    private $_notificationsManagement = 0;
    /** @var Service_MspApiClient_Request_Struct_UserPrivileges */
    private $_privileges;
    /** @var integer */
    private $_privileged;
    /** @var  boolean */
    private $_roles;
    /** @var int  */
    private $_status = self::STATUS_ENABLE;

    public function __construct()
    {
        parent::__construct();
        $this->setPrivileges(new Service_MspApiClient_Request_Struct_UpdateUserPrivileges());
    }

    /**
     * @return array
     */
    public function toArray()
    {
        $result = [];
        if ($this->_isFieldChanged(static::FIELD_EMAIL)) {
            $result[static::FIELD_EMAIL] = $this->getEmail();
        }

        if ($this->_isFieldChanged(static::FIELD_FIRSTNAME)) {
            $result[static::FIELD_FIRSTNAME] = $this->getFirstName();
        }

        if ($this->_isFieldChanged(static::FIELD_LASTNAME)) {
            $result[static::FIELD_LASTNAME] = $this->getLastName();
        }

        if ($this->_isFieldChanged(static::FIELD_LANGUAGE)) {
            $result[static::FIELD_LANGUAGE] = $this->getLanguage();
        }

        if ($this->_isFieldChanged(static::FIELD_NOTIFICATIONS_BACKUP)) {
            $result[static::FIELD_NOTIFICATIONS_BACKUP] = $this->getNotificationsBackup()->getValue();
        }

        if ($this->_isFieldChanged(static::FIELD_NOTIFICATIONS_MANAGEMENT)) {
            $result[static::FIELD_NOTIFICATIONS_MANAGEMENT] = $this->getNotificationsManagement();
        }

        if ($this->getPrivileges()->isExistsUpdateFields()) {
            $result[static::FIELD_PRIVILEGES] = $this->getPrivileges()->toArray();
        }

        if ($this->_isFieldChanged(static::FIELD_STATUS)) {
            $result[static::FIELD_STATUS] = $this->getStatus();
        }

        if ($this->_isFieldChanged(static::FIELD_PRIVILEGED)) {
            $result[static::FIELD_PRIVILEGED] = $this->getPrivileged();
        }

        if ($this->_isFieldChanged(static::FIELD_ROLES)) {
            $result[static::FIELD_ROLES] = $this->getRoles();
        }
        return $result;
    }

    /**
     * @param string $email
     */
    public function setEmail($email)
    {
        $this->_markFieldAsUpdated(static::FIELD_EMAIL);
        $this->_email = $email;
    }

    /**
     * @return string
     */
    public function getEmail()
    {
        return $this->_email;
    }

    /**
     * @param string $firstName
     */
    public function setFirstName($firstName)
    {
        $this->_markFieldAsUpdated(static::FIELD_FIRSTNAME);
        $this->_firstName = $firstName;
    }

    /**
     * @return string
     */
    public function getFirstName()
    {
        return $this->_firstName;
    }

    /**
     * @param string $lastName
     */
    public function setLastName($lastName)
    {
        $this->_markFieldAsUpdated(static::FIELD_LASTNAME);
        $this->_lastName = $lastName;
    }

    /**
     * @return string
     */
    public function getLastName()
    {
        return $this->_lastName;
    }

    /**
     * @param Enum_NotificationsBackup $notificationsBackup
     */
    public function setNotificationsBackup(Enum_NotificationsBackup $notificationsBackup)
    {
        $this->_markFieldAsUpdated(static::FIELD_NOTIFICATIONS_BACKUP);
        $this->_notificationsBackup = $notificationsBackup;
    }

    /**
     * @return Enum_NotificationsBackup
     */
    public function getNotificationsBackup()
    {
        return $this->_notificationsBackup;
    }

    /**
     * @param int $notificationsManagement
     */
    public function setNotificationsManagement($notificationsManagement)
    {
        $this->_markFieldAsUpdated(static::FIELD_NOTIFICATIONS_MANAGEMENT);
        $this->_notificationsManagement = $notificationsManagement;
    }

    /**
     * @return int
     */
    public function getNotificationsManagement()
    {
        return $this->_notificationsManagement;
    }

    /**
     * @param Service_MspApiClient_Request_Struct_UserPrivileges $privileges
     */
    public function setPrivileges(Service_MspApiClient_Request_Struct_UserPrivileges $privileges)
    {
        $this->_privileges = $privileges;
    }

    /**
     * @return Service_MspApiClient_Request_Struct_UserPrivileges
     */
    public function getPrivileges()
    {
        return $this->_privileges;
    }


    /**
     * @return int
     */
    public function getPrivileged()
    {
        return $this->_privileged;
    }

    /**
     * @param int $privileged
     */
    public function setPrivileged($privileged)
    {
        $this->_markFieldAsUpdated(static::FIELD_PRIVILEGED);
        $this->_privileged = $privileged;
    }

    /**
     * @param int $status
     */
    public function setStatus($status)
    {
        $this->_markFieldAsUpdated(static::FIELD_STATUS);
        $this->_status = $status;
    }

    /**
     * @return int
     */
    public function getStatus()
    {
        return $this->_status;
    }

    public function getRoles()
    {
        $this->_roles;
    }

    public function setRoles($roles)
    {
        $this->_markFieldAsUpdated(static::FIELD_ROLES);
        $this->_roles = $roles;
    }

    /**
     * @return string
     */
    public function getLanguage()
    {
        return $this->_language;
    }

    /**
     * @param string $language
     */
    public function setLanguage($language)
    {
        $this->_markFieldAsUpdated(static::FIELD_LANGUAGE);
        $this->_language = $language;
    }
}
