<?php
/**
 * @Copyright © 2002-2018 Acronis International GmbH. All rights reserved
 */
namespace Acronis\App\Services\CountersManager;


use Acronis\App\Base\ApplicationCounter;
use Symfony\Component\Yaml\Yaml;
use Acronis\App\CloudApi\ApiInterface as CloudApi;

class CountersGenerator
{
    private $counters;

    public function __construct($yaml)
    {
        foreach (Yaml::parse($yaml) as $counter) {
            if (!isset($counter['application_type'])) {
                $counter['application_type'] = CloudApi::APPLICATION_TYPE_BACKUP;
            }
            if (isset($counter['unit'])) {
                $counter['counter_unit'] = $counter['unit'];
                $counter['offering_item_unit'] = $counter['unit'];
                unset($counter['unit']);
            }

            if (isset($counter['editions'])) {
                $editions = $counter['editions'];
                unset($counter['editions']);
                foreach ($editions['editions'] as $edition) {
                    $editionCounter = $counter;
                    unset($editionCounter['infra']);
                    unset($editionCounter['infra_capability']);
                    unset($editionCounter['depends_on']);
                    unset($editionCounter['partner_offering_items']);
                    unset($editionCounter['aggregation_rules']);
                    $editionCounter['counter_name'] = $this->getCounterName($counter['counter_name'], $edition);
                    $editionCounter['offering_item_name'] = $this->getOfferingItemName($counter['offering_item_name'], $edition);
                    if (isset($editions['is_infra'])) {
                        $editionCounter['is_infra'] = $editions['is_infra'];
                    }
                    if (isset($editions['infra_capability'])) {
                        $editionCounter['infra_capability'] = $editions['infra_capability'];
                    }
                    if (isset($editions['depends_on'])) {
                        $editionCounter['depends_on'] = [];
                        foreach ($editions['depends_on'] as $partnerOfferingItem) {
                            $editionCounter['depends_on'][] = $this->getDependenceName($partnerOfferingItem, $edition);
                        }
                    }
                    if (isset($editions['partner_offering_items'])) {
                        $editionCounter['partner_offering_items'] = [];
                        foreach ($editions['partner_offering_items'] as $partnerOfferingItem) {
                            $editionCounter['partner_offering_items'][] = $this->getOfferingItemName($partnerOfferingItem, $edition);
                        }
                    }
                    if (isset($editions['aggregation_rules'])) {
                        $aggregationRules = array_merge([ApplicationCounter::AGGREGATION_EDITION => $edition], $editions['aggregation_rules']);
                        $editionCounter['aggregation_rules'] = $aggregationRules;
                    }
                    $this->counters[] = $editionCounter;
                }
            }
            $this->counters[] = $counter;
        }
    }

    private function getDependenceName($baseName, $edition)
    {
        return $this->getCounterName($baseName, $edition);
    }

    private function getCounterName($baseName, $edition)
    {
        switch ($edition) {
            case 'advanced':
                return 'Adv' . $baseName;
            case 'cyber_protect_adv':
                return 'PAdv' . $baseName;
            case 'cyber_protect_dre':
                return 'PDre' . $baseName;
            case 'cyber_protect_std':
                return 'P' . $baseName;
            case 'disaster_recovery':
                return 'Dre' . $baseName;
            default:
                throw new \Exception(\Str::format('Unsupported edition %s', $edition));
        }
    }

    private function getOfferingItemName($baseName, $edition)
    {
        switch ($edition) {
            case 'advanced':
                return 'adv_' . $baseName;
            case 'cyber_protect_adv':
                return 'p_adv_' . $baseName;
            case 'cyber_protect_dre':
                return 'p_dre_' . $baseName;
            case 'cyber_protect_std':
                return 'p_' . $baseName;
            case 'disaster_recovery':
                return 'dre_' . $baseName;
            default:
                throw new \Exception(\Str::format('Unsupported edition %s', $edition));
        }
    }

    public function getCounters()
    {
        return $this->counters;
    }

}