<?php
/**
 * @Copyright © 2002-2019 Acronis International GmbH. All rights reserved
 */

use Acronis\App\Base\ApplicationCounter as Counter;
use Acronis\App\CloudApi\ApiInterface as CloudApi;
use Acronis\App\Utils\UomConverter as Uom;
use Acronis\Cloud\Client\Model\Infra\InfraCap;

/**
 * Available types of a counter:
 *   feature - will be disabled/enabled if limit equals/not equals to 0
 *   limit - can be used to get limit only
 *   usage - can be used to set usage only
 *   counter - limit and usage are available
 * Available measurement unit types of a counter:
 *    Unit: u - quantity of units
 *    Storage: b, kb, mb, gb
 *    Time: s, m, h, d
 * Format:
 * return [
 *   [
 *       'application_type' => 'backup|files_cloud|notary',
 *       'counter_type' => 'feature|limit|usage|counter',
 *       'counter_name' => '<counter name>',
 *       'counter_unit' => '<counter unit of measurement>',
 *       'offering_item_name' => '<offering item name>',
 *       'offering_item_unit' => '<offering item unit of measurement>',
 *       'infra_capability' => 'backup|disaster_recovery|files_cloud',
 *       'is_infra' => true|false,
 *       'is_ranged' => true|false,
 *       'is_fake' => true|false,
 *       'tenant_types' => null|['CUSTOMER', 'PARTNER', 'RESELLER'],
 *   ],
 * // ...
 * ];
 */

return [
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::STORAGE_USAGE,
        'counter_unit' => Uom::BYTES,
        'offering_item_name' => CloudApi::OFFERING_ITEM_STORAGE,
        'offering_item_unit' => Uom::BYTES,
        'infra_capability' => InfraCap::BACKUP,
        'is_for_user' => true,
        'is_infra' => true,
        'partner_offering_items' => [
            CloudApi::OFFERING_ITEM_CHILD_STORAGES,
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::LOCAL_STORAGE_USAGE,
        'counter_unit' => Uom::BYTES,
        'offering_item_name' => CloudApi::OFFERING_ITEM_LOCAL_STORAGE,
        'offering_item_unit' => Uom::BYTES,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::WORKSTATION_COUNT,
        'counter_unit' => Uom::UNITS,
        'offering_item_name' => CloudApi::OFFERING_ITEM_WORKSTATIONS,
        'offering_item_unit' => Uom::UNITS,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::SERVER_COUNT,
        'counter_unit' => Uom::UNITS,
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_SERVERS,
        'offering_item_unit' => Uom::UNITS,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::VM_COUNT,
        'counter_unit' => Uom::UNITS,
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_VMS,
        'offering_item_unit' => Uom::UNITS,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::MOBILE_DEVICE_COUNT,
        'counter_unit' => Uom::UNITS,
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_MOBILES,
        'offering_item_unit' => Uom::UNITS,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::MAILBOX_COUNT,
        'counter_unit' => Uom::UNITS,
        'offering_item_name' => CloudApi::OFFERING_ITEM_MAILBOXES,
        'offering_item_unit' => Uom::UNITS,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_LIMIT,
        'counter_name' => tenant::MAILBOX_INSTANCE_SIZE,
        'counter_unit' => Uom::BYTES,
        'offering_item_name' => CloudApi::OFFERING_ITEM_MAILBOX_INSTANCE_SIZE,
        'offering_item_unit' => Uom::BYTES,
        'is_fake' => true,
        'depends_on' => [
            tenant::MAILBOX_COUNT,
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::O365_MAILBOXES,
        'counter_unit' => Uom::UNITS,
        'offering_item_name' => CloudApi::OFFERING_ITEM_O365_MAILBOXES,
        'offering_item_unit' => Uom::UNITS,
        'depends_on' => [
            tenant::MAILBOX_COUNT,
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::O365_ONE_DRIVE,
        'counter_unit' => Uom::UNITS,
        'offering_item_name' => CloudApi::OFFERING_ITEM_O365_ONEDRIVE,
        'offering_item_unit' => Uom::UNITS,
        'depends_on' => [
            tenant::MAILBOX_COUNT,
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::O365_SHARE_POINT_SITES_COUNT,
        'counter_unit' => Uom::UNITS,
        'offering_item_name' => CloudApi::OFFERING_ITEM_O365_SHAREPOINT_SITES,
        'offering_item_unit' => Uom::UNITS,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::WEB_HOSTING_SERVER_COUNT,
        'counter_unit' => Uom::UNITS,
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_WEB_HOSTING_SERVERS,
        'offering_item_unit' => Uom::UNITS,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::WEBSITE_COUNT,
        'counter_unit' => Uom::UNITS,
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_WEBSITES,
        'offering_item_unit' => Uom::UNITS,
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DR_STORAGE_USAGE,
        'counter_unit' => Uom::BYTES,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DR_STORAGE,
        'offering_item_unit' => Uom::BYTES,
        'infra_capability' => InfraCap::DISASTER_RECOVERY,
        'is_infra' => true,
        'depends_on' => [
            tenant::STORAGE_USAGE,
        ],
        'partner_offering_items' => [
            'dr_child_storages',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DR_COMPUTE_POINTS_COUNT,
        'counter_unit' => Uom::HOURS, // units per hours
        'offering_item_name' => CloudApi::OFFERING_ITEM_COMPUTE_POINTS,
        'offering_item_unit' => Uom::SECONDS, // units per hours
        'infra_capability' => InfraCap::DISASTER_RECOVERY,
        'is_infra' => true,
        'is_ranged' => true,
        'depends_on' => [
            tenant::STORAGE_USAGE,
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DR_PUBLIC_IPS_COUNT,
        'counter_unit' => Uom::UNITS,
        'offering_item_name' => CloudApi::OFFERING_ITEM_PUBLIC_IPS,
        'offering_item_unit' => Uom::UNITS,
        'infra_capability' => InfraCap::DISASTER_RECOVERY,
        'is_infra' => true,
        'depends_on' => [
            tenant::STORAGE_USAGE,
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DR_CLOUD_SERVERS_COUNT,
        'counter_unit' => Uom::UNITS,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DR_CLOUD_SERVERS,
        'offering_item_unit' => Uom::UNITS,
        'infra_capability' => InfraCap::DISASTER_RECOVERY,
        'is_infra' => true,
        'depends_on' => [
            tenant::STORAGE_USAGE,
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::DR_INTERNET_ACCESS,
        'counter_unit' => Uom::UNITS,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DR_INTERNET_ACCESS,
        'offering_item_unit' => Uom::UNITS,
        'infra_capability' => InfraCap::DISASTER_RECOVERY,
        'is_infra' => true,
        'depends_on' => [
            tenant::STORAGE_USAGE,
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::ACRONIS_STORAGE_USAGE,
        'counter_unit' => Uom::BYTES,
        'offering_item_name' => CloudApi::OFFERING_ITEM_STORAGE,
        'offering_item_unit' => Uom::BYTES,
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis', null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::PROVIDER_STORAGE_USAGE,
        'counter_unit' => Uom::BYTES,
        'offering_item_name' => CloudApi::OFFERING_ITEM_STORAGE,
        'offering_item_unit' => Uom::BYTES,
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'infra.affinity' => ['own', 'child'],
            'infra.backend_type' => ['acronis',null,'google','azure']
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::GOOGLE_STORAGE_USAGE,
        'counter_unit' => Uom::BYTES,
        'offering_item_name' => CloudApi::OFFERING_ITEM_STORAGE,
        'offering_item_unit' => Uom::BYTES,
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'google',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::ADV_SERVICE_PROVIDER_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'AdvStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'advanced',
            'infra.affinity' => ['own','child'],
            'infra.backend_type' => ['acronis',null,'google','azure'],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::ADV_GSUITE_GOOGLE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_GOOGLE_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::ADV_GSUITE_GOOGLE_MAIL,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_GOOGLE_MAIL,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::ADV_GSUITE_GOOGLE_TEAM_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_GOOGLE_TEAM_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_GSUITE_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_GSUITE_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_O365_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_O365_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_MOBILE_DEVICE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_MOBILES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::ADV_ACRONIS_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'AdvStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'advanced',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis',null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::ADV_AZURE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'AdvStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'advanced',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'azure',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::ADV_GOOGLE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'AdvStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'advanced',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'google',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::ADV_O365_MAILBOXES,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_O365_MAILBOXES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::ADV_O365_ONE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_O365_ONEDRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_O365_SHARE_POINT_SITES_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_O365_SHAREPOINT_SITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_STORAGE_USAGE,
        'counter_unit' => 'b',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'partner_offering_items' => [
            'adv_child_storages',
        ],
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_VM_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_VMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_WEB_HOSTING_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_WEB_HOSTING_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_WEBSITE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_WEBSITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_WORKSTATION_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_WORKSTATIONS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_ADV_PARTNER_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PAdvStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
            'infra.affinity' => ['own','child'],
            'infra.backend_type' => ['acronis',null,'google','azure'],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_ADV_GSUITE_GOOGLE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_GOOGLE_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_ADV_GSUITE_GOOGLE_MAIL,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_GOOGLE_MAIL,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_ADV_GSUITE_GOOGLE_TEAM_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_GOOGLE_TEAM_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_GSUITE_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_GSUITE_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_O365_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_O365_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_MOBILE_DEVICE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_MOBILES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_ADV_ACRONIS_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PAdvStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis',null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_ADV_AZURE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PAdvStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'azure',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_ADV_GOOGLE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PAdvStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'google',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_ADV_O365_MAILBOXES,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_O365_MAILBOXES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_ADV_O365_ONE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_O365_ONEDRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_O365_SHARE_POINT_SITES_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_O365_SHAREPOINT_SITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_STORAGE_USAGE,
        'counter_unit' => 'b',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'partner_offering_items' => [
            'p_adv_child_storages',
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_VM_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_VMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_WEB_HOSTING_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_WEB_HOSTING_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_WEBSITE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_WEBSITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_WORKSTATION_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_WORKSTATIONS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_DRE_PARTNER_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PDreStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
            'infra.affinity' => ['own','child'],
            'infra.backend_type' => ['acronis',null,'google','azure'],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_COMPUTE_POINTS_COUNT,
        'counter_unit' => 'h',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_COMPUTE_POINTS,
        'offering_item_unit' => 's',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'is_ranged' => true,
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_DRE_DR_PARTNER_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_DR_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'depends_on' => [
            'PDreDrStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
            'infra.affinity' => ['own','child'],
            'infra.backend_type' => ['acronis',null,'google','azure'],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_CLOUD_SERVERS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_DR_CLOUD_SERVERS,
        'offering_item_unit' => 'u',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_DRE_INTERNET_ACCESS,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_DR_INTERNET_ACCESS,
        'offering_item_unit' => 'u',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_DR_STORAGE_USAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_DR_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'partner_offering_items' => [
            'p_dre_dr_child_storages',
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_DRE_GSUITE_GOOGLE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_GOOGLE_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_DRE_GSUITE_GOOGLE_MAIL,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_GOOGLE_MAIL,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_DRE_GSUITE_GOOGLE_TEAM_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_GOOGLE_TEAM_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_GSUITE_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_GSUITE_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_O365_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_O365_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_MOBILE_DEVICE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_MOBILES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_DRE_DR_ACRONIS_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_DR_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'depends_on' => [
            'PDreDrStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis',null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_DRE_GOOGLE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PDreStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'google',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_DRE_AZURE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PDreStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'azure',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_DRE_ACRONIS_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PDreStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis',null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_DRE_O365_MAILBOXES,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_O365_MAILBOXES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_DRE_O365_ONE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_O365_ONEDRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_O365_SHARE_POINT_SITES_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_O365_SHAREPOINT_SITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_PUBLIC_IPS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_PUBLIC_IPS,
        'offering_item_unit' => 'u',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_STORAGE_USAGE,
        'counter_unit' => 'b',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'partner_offering_items' => [
            'p_dre_child_storages',
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_VM_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_VMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_WEB_HOSTING_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_WEB_HOSTING_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_WEBSITE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_WEBSITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_WORKSTATION_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_WORKSTATIONS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_PARTNER_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
            'infra.affinity' => ['own','child'],
            'infra.backend_type' => ['acronis',null,'google','azure'],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_GSUITE_GOOGLE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_GOOGLE_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_GSUITE_GOOGLE_MAIL,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_GOOGLE_MAIL,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::P_GSUITE_GOOGLE_TEAM_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_GOOGLE_TEAM_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_GSUITE_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_GSUITE_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::PO365_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_O365_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_MOBILE_DEVICE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_MOBILES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_GOOGLE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'google',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_AZURE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'azure',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::P_ACRONIS_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'PStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis',null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::PO365_MAILBOXES,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_O365_MAILBOXES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::PO365_ONE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_O365_ONEDRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::PO365_SHARE_POINT_SITES_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_O365_SHAREPOINT_SITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_STORAGE_USAGE,
        'counter_unit' => 'b',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'partner_offering_items' => [
            'p_child_storages',
        ],
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_VM_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_VMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_WEB_HOSTING_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_WEB_HOSTING_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_WEBSITE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_WEBSITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_WORKSTATION_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_WORKSTATIONS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::DRE_SERVICE_PROVIDER_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'DreStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
            'infra.affinity' => ['own','child'],
            'infra.backend_type' => ['acronis',null,'google','azure'],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_COMPUTE_POINTS_COUNT,
        'counter_unit' => 'h',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_COMPUTE_POINTS,
        'offering_item_unit' => 's',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'is_ranged' => true,
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::DRE_DR_PARTNER_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_DR_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'depends_on' => [
            'DreDrStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
            'infra.affinity' => ['own','child'],
            'infra.backend_type' => ['acronis',null,'google','azure'],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_CLOUD_SERVERS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_DR_CLOUD_SERVERS,
        'offering_item_unit' => 'u',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::DRE_INTERNET_ACCESS,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_DR_INTERNET_ACCESS,
        'offering_item_unit' => 'u',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_DR_STORAGE_USAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_DR_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'partner_offering_items' => [
            'dre_dr_child_storages',
        ],
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::DRE_GSUITE_GOOGLE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_GOOGLE_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::DRE_GSUITE_GOOGLE_MAIL,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_GOOGLE_MAIL,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::DRE_GSUITE_GOOGLE_TEAM_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_GOOGLE_TEAM_DRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_GSUITE_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_GSUITE_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_O365_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_O365_SEATS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_MOBILE_DEVICE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_MOBILES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::DRE_DR_ACRONIS_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_DR_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'depends_on' => [
            'DreDrStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis',null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::DRE_GOOGLE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'DreStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'google',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::DRE_AZURE_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'DreStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'azure',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::DRE_ACRONIS_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'depends_on' => [
            'DreStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis',null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::DRE_O365_MAILBOXES,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_O365_MAILBOXES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::DRE_O365_ONE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_O365_ONEDRIVE,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_O365_SHARE_POINT_SITES_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_O365_SHAREPOINT_SITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_PUBLIC_I_PS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_PUBLIC_IPS,
        'offering_item_unit' => 'u',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_STORAGE_USAGE,
        'counter_unit' => 'b',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'backup',
        'partner_offering_items' => [
            'dre_child_storages',
        ],
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_VM_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_VMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_WEB_HOSTING_SERVER_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_WEB_HOSTING_SERVERS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_WEBSITE_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_WEBSITES,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_WORKSTATION_COUNT,
        'counter_unit' => 'u',
        'is_for_user' => true,
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_WORKSTATIONS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::DR_ACRONIS_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DR_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'depends_on' => [
            'DRStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'standard',
            'infra.affinity' => 'inherited',
            'infra.backend_type' => ['acronis',null],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::DR_PARTNER_HOSTED_STORAGE,
        'counter_unit' => 'b',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DR_STORAGE,
        'offering_item_unit' => 'b',
        'is_infra' => true,
        'infra_capability' => 'disaster_recovery',
        'depends_on' => [
            'DRStorageUsage',
        ],
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'edition' => 'standard',
            'infra.affinity' => ['own','child'],
            'infra.backend_type' => ['acronis',null,'google','azure'],
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::GSUITE_SEATS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_GSUITE_SEATS,
        'offering_item_unit' => 'u',
        'infra_capability' => 'backup',
        'aggregation_rules' => [
            'edition' => 'standard',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::GSUITE_GOOGLE_TEAM_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_GOOGLE_TEAM_DRIVE,
        'offering_item_unit' => 'u',
        'infra_capability' => 'backup',
        'aggregation_rules' => [
            'edition' => 'standard',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::GSUITE_GOOGLE_MAIL,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_GOOGLE_MAIL,
        'offering_item_unit' => 'u',
        'infra_capability' => 'backup',
        'aggregation_rules' => [
            'edition' => 'standard',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_FEATURE,
        'counter_name' => tenant::GSUITE_GOOGLE_DRIVE,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_GOOGLE_DRIVE,
        'offering_item_unit' => 'u',
        'infra_capability' => 'backup',
        'aggregation_rules' => [
            'edition' => 'standard',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::ADV_O365_TEAMS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_ADV_O365_TEAMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'advanced',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_ADV_O365_TEAMS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_ADV_O365_TEAMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_adv',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::P_DRE_O365_TEAMS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_DRE_O365_TEAMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_dre',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::PO365_TEAMS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_P_O365_TEAMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'cyber_protect_std',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::DRE_O365_TEAMS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_DRE_O365_TEAMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'disaster_recovery',
        ],
    ],
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_COUNTER,
        'counter_name' => tenant::O365_TEAMS_COUNT,
        'counter_unit' => 'u',
        'offering_item_name' => CloudApi::OFFERING_ITEM_O365_TEAMS,
        'offering_item_unit' => 'u',
        'aggregation_rules' => [
            'edition' => 'standard',
        ],
    ],
// scripts_app_application_counters_add this code is used for code generation, do not remove!
    [
        'application_type' => CloudApi::APPLICATION_TYPE_BACKUP,
        'counter_type' => Counter::TYPE_USAGE,
        'counter_name' => tenant::AZURE_STORAGE_USAGE,
        'counter_unit' => Uom::BYTES,
        'offering_item_name' => CloudApi::OFFERING_ITEM_STORAGE,
        'offering_item_unit' => Uom::BYTES,
        'tenant_types' => [
            tenant::TYPE_PARTNER,
            tenant::TYPE_RESELLER,
        ],
        'aggregation_rules' => [
            'infra.affinity' => 'inherited',
            'infra.backend_type' => 'azure',
        ],
    ],
];

