<?php
/**
 * @Copyright © 2002-2017 Acronis International GmbH. All rights reserved
 */
class Settings extends AbstractSettings
{
    const BILLING_CONFIG_FILE = 'ba-api.ini';
    const APPLICATION_CONFIG_FILE = 'application_settings.ini';

    const BILLING_CONFIG_NAME = 'Billing';
    const APPLICATION_CONFIG_NAME = 'Application';

    const EXCEPTION_BILLING_MODULE_IS_NOT_CONFIGURED_MESSAGE = 'Billing module is not configured';


    /** @var object */
    private $billingConfig;

    /** @var object */
    private $applicationConfig;

    /** @var Settings */
    private static $instance;

    private function __construct()
    {
    }

    /**
     * @return Settings
     */
    public static function getInstance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new Settings();
        }
        return self::$instance;
    }

    /**
     * @return object
     * @throws Exception
     */
    public function getBillingConfig()
    {
        if (is_null($this->billingConfig)) {
            $fileName = DIR_CONFIG . self::BILLING_CONFIG_FILE;

            $data = $this->readConfig($fileName, self::BILLING_CONFIG_NAME);

            $config = new stdClass();
            $config->host = isset($data['host']) ? trim($data['host']) : null;

            if (empty($config->host)) {
                Log::getInstance()->error(sprintf(self::MODULE_IS_NOT_CONFIGURED_MESSAGE, self::BILLING_CONFIG_NAME));
                throw new Exception(sprintf(self::MODULE_IS_NOT_CONFIGURED_MESSAGE, self::BILLING_CONFIG_NAME));
            }

            $config->secure = isset($data['secure']) ? (boolean)intval($data['secure']) : true;
            $config->port = isset($data['port']) ? intval($data['port']) : null;
            $config->path = isset($data['path']) ? trim($data['path']) : null;
            $config->auth = isset($data['auth']) ? (boolean)intval($data['auth']) : false;
            $config->username = isset($data['username']) ? trim($data['username']) : null;
            $config->password = isset($data['password']) ? trim($data['password']) : null;

            $this->billingConfig = $config;
        }

        return $this->billingConfig;
    }

    /**
     * @return object
     * @throws Exception
     */
    public function getApplicationConfig()
    {
        if (is_null($this->applicationConfig)) {
            $fileName = DIR_CONFIG . self::APPLICATION_CONFIG_FILE;

            $data = $this->readConfig($fileName, self::APPLICATION_CONFIG_NAME);

            $config = new stdClass();

            $config->service_auto_assignation = isset($data['service_auto_assignation'])
                ? (boolean)intval($data['service_auto_assignation'])
                : false;
            $config->ccpv1_show_staff_members = isset($data['ccpv1_show_staff_members'])
                ? (boolean)intval($data['ccpv1_show_staff_members'])
                : false;

            $this->applicationConfig = $config;
        }

        return $this->applicationConfig;
    }
}
